@@ -8,10 +8,10 @@ autoreconf
   --with-ptw32=$PREFIX/i686-w64-mingw32.static \
   --with-libiconv-prefix=$PREFIX/iconv \
   --enable-static \
-  PTW32_LIBS="-lpthread -lpcreposix -lpcre -lregex" \
+  PTW32_LIBS="-lpthread -lpcreposix -lpcre" \
   FLTK_CONFIG=$PREFIX/i686-w64-mingw32.static/bin/fltk-config
 
-make -j 3
+make -j 8
 $PREFIX/bin/i686-w64-mingw32.static-strip src/flrig.exe
 make nsisinst
 mv src/*setup*exe .
