@@ -47,7 +47,6 @@ Hspinner *spnrOUTER = (Hspinner *)0;
 Hspinner *spnrNOTCH = (Hspinner *)0;
 Hspinner *spnrMICGAIN = (Hspinner *)0;
 
-static const int freq_sel_widths[]={110, 70, 70, 0};
 static Fl_Double_Window *meter_scale_dialog = (Fl_Double_Window *)0;
 static Fl_Double_Window *meter_filters = (Fl_Double_Window *)0;
 
@@ -136,6 +135,23 @@ Fl_Button *btn_yaesu_select_10 = (Fl_Button *)0;
 Fl_Button *btn_yaesu_select_11 = (Fl_Button *)0;
 Fl_ComboBox *op_yaesu_select60 = (Fl_ComboBox *)0;
 
+Fl_Group  *tab_ft991_bands = (Fl_Group *)0;
+Fl_Button *btn_ft991_select_1 = (Fl_Button *)0;
+Fl_Button *btn_ft991_select_2 = (Fl_Button *)0;
+Fl_Button *btn_ft991_select_3 = (Fl_Button *)0;
+Fl_Button *btn_ft991_select_4 = (Fl_Button *)0;
+Fl_Button *btn_ft991_select_5 = (Fl_Button *)0;
+Fl_Button *btn_ft991_select_6 = (Fl_Button *)0;
+Fl_Button *btn_ft991_select_7 = (Fl_Button *)0;
+Fl_Button *btn_ft991_select_8 = (Fl_Button *)0;
+Fl_Button *btn_ft991_select_9 = (Fl_Button *)0;
+Fl_Button *btn_ft991_select_10 = (Fl_Button *)0;
+Fl_Button *btn_ft991_select_11 = (Fl_Button *)0;
+Fl_Button *btn_ft991_select_12 = (Fl_Button *)0;
+Fl_Button *btn_ft991_select_13 = (Fl_Button *)0;
+Fl_PL_tone *choice_ft991_tTONE = (Fl_PL_tone *)0;
+Fl_PL_tone *choice_ft991_rTONE = (Fl_PL_tone *)0;
+
 Fl_Group *tab_FT8n_bands = (Fl_Group *)0;
 Fl_Button *btn_FT8n_select_1 = (Fl_Button *)0;
 Fl_Button *btn_FT8n_select_2 = (Fl_Button *)0;
@@ -261,6 +277,16 @@ Fl_Button *btnUser14 = (Fl_Button*)0;
 Fl_Button *btnUser15 = (Fl_Button*)0;
 Fl_Button *btnUser16 = (Fl_Button*)0;
 
+Fl_Group  *genericUser_3 = (Fl_Group *)0;
+Fl_Button *btnUser17 = (Fl_Button*)0;
+Fl_Button *btnUser18 = (Fl_Button*)0;
+Fl_Button *btnUser19 = (Fl_Button*)0;
+Fl_Button *btnUser20 = (Fl_Button*)0;
+Fl_Button *btnUser21 = (Fl_Button*)0;
+Fl_Button *btnUser22 = (Fl_Button*)0;
+Fl_Button *btnUser23 = (Fl_Button*)0;
+Fl_Button *btnUser24 = (Fl_Button*)0;
+
 Fl_Group *genericRXB = (Fl_Group *)0;
 Hspinner *cntRIT = (Hspinner *)0;
 Hspinner *cntXIT = (Hspinner *)0;
@@ -431,6 +457,10 @@ static void cb_mnuPTT(Fl_Menu_*, void*) {
 	open_ptt_tab();
 }
 
+static void cb_mnuGPIO(Fl_Menu_*, void*) {
+	open_gpio_tab();
+}
+
 static void cb_mnuAUX(Fl_Menu_*, void *) {
 	open_aux_tab();
 }
@@ -823,6 +853,14 @@ static void cb_btnUser( Fl_Button * o, void *d) {
 			case 14: cb_send_command(progStatus.shftcmd14, cmdResponse); break;
 			case 15: cb_send_command(progStatus.shftcmd15, cmdResponse); break;
 			case 16: cb_send_command(progStatus.shftcmd16, cmdResponse); break;
+			case 17: cb_send_command(progStatus.shftcmd17, cmdResponse); break;
+			case 18: cb_send_command(progStatus.shftcmd18, cmdResponse); break;
+			case 19: cb_send_command(progStatus.shftcmd19, cmdResponse); break;
+			case 20: cb_send_command(progStatus.shftcmd20, cmdResponse); break;
+			case 21: cb_send_command(progStatus.shftcmd21, cmdResponse); break;
+			case 22: cb_send_command(progStatus.shftcmd22, cmdResponse); break;
+			case 23: cb_send_command(progStatus.shftcmd23, cmdResponse); break;
+			case 24: cb_send_command(progStatus.shftcmd24, cmdResponse); break;
 		}
 	} else {
 		switch (val) {
@@ -842,6 +880,14 @@ static void cb_btnUser( Fl_Button * o, void *d) {
 			case 14: cb_send_command(progStatus.command14, cmdResponse); break;
 			case 15: cb_send_command(progStatus.command15, cmdResponse); break;
 			case 16: cb_send_command(progStatus.command16, cmdResponse); break;
+			case 17: cb_send_command(progStatus.command17, cmdResponse); break;
+			case 18: cb_send_command(progStatus.command18, cmdResponse); break;
+			case 19: cb_send_command(progStatus.command19, cmdResponse); break;
+			case 20: cb_send_command(progStatus.command20, cmdResponse); break;
+			case 21: cb_send_command(progStatus.command21, cmdResponse); break;
+			case 22: cb_send_command(progStatus.command22, cmdResponse); break;
+			case 23: cb_send_command(progStatus.command23, cmdResponse); break;
+			case 24: cb_send_command(progStatus.command24, cmdResponse); break;
 		}
 	}
 }
