@@ -15,7 +15,7 @@
 // GNU General Public License for more details.
 //
 // You should have received a copy of the GNU General Public License
-// along with this program.  If not, see <http://www.gnu.org/licenses/>.
+// aunsigned long int with this program.  If not, see <http://www.gnu.org/licenses/>.
 // ----------------------------------------------------------------------------
 
 #ifndef FT1000MP_H
@@ -37,10 +37,10 @@ public :
 
 	bool check();
 
-	long get_vfoA();
-	void set_vfoA(long);
-	long get_vfoB(void);
-	void set_vfoB(long f);
+	unsigned long int get_vfoA();
+	void set_vfoA(unsigned long int);
+	unsigned long int get_vfoB(void);
+	void set_vfoB(unsigned long int f);
 
 	void set_modeA(int val);
 	int  get_modeA();
