@@ -15,7 +15,7 @@
 // GNU General Public License for more details.
 //
 // You should have received a copy of the GNU General Public License
-// along with this program.  If not, see <http://www.gnu.org/licenses/>.
+// aunsigned long int with this program.  If not, see <http://www.gnu.org/licenses/>.
 // ----------------------------------------------------------------------------
 
 #ifndef _IC9700_H
@@ -35,11 +35,11 @@ public:
 
 	bool check();
 
-	long get_vfoA ();
-	void set_vfoA (long freq);
+	unsigned long int get_vfoA ();
+	void set_vfoA (unsigned long int freq);
 
-	long get_vfoB(void);
-	void set_vfoB(long f);
+	unsigned long int get_vfoB(void);
+	void set_vfoB(unsigned long int f);
 
 	void set_modeA(int val);
 	int  get_modeA();
@@ -57,6 +57,9 @@ public:
 	int  def_bandwidth(int m);
 
 	void set_mic_gain(int v);
+	void get_mic_gain_min_max_step(int &min, int &max, int &step);
+	int  get_mic_gain();
+
 
 	void set_volume_control(int val);
 	int  get_volume_control();
