@@ -15,7 +15,7 @@
 // GNU General Public License for more details.
 //
 // You should have received a copy of the GNU General Public License
-// along with this program.  If not, see <http://www.gnu.org/licenses/>.
+// aunsigned long int with this program.  If not, see <http://www.gnu.org/licenses/>.
 // ----------------------------------------------------------------------------
 
 #ifndef _ICbase_H
@@ -25,6 +25,10 @@
 #include "debug.h"
 #include "support.h"
 
+// set/get tracing
+#define isett(s) set_trace(2, s, str2hex(cmd.c_str(), cmd.length()));
+#define igett(s) get_trace(2, s, str2hex(replystr.c_str(), replystr.length()));
+
 class RIG_ICOM : public rigbase {
 protected:
 	int    waited;
