@@ -15,7 +15,7 @@
 // GNU General Public License for more details.
 //
 // You should have received a copy of the GNU General Public License
-// along with this program.  If not, see <http://www.gnu.org/licenses/>.
+// aunsigned long int with this program.  If not, see <http://www.gnu.org/licenses/>.
 // ----------------------------------------------------------------------------
 
 #ifndef _TS870S_H
@@ -49,10 +49,10 @@ public:
 
 	bool check();
 
-	long get_vfoA();
-	void set_vfoA(long);
-	long get_vfoB();
-	void set_vfoB(long);
+	unsigned long int get_vfoA();
+	void set_vfoA(unsigned long int);
+	unsigned long int get_vfoB();
+	void set_vfoB(unsigned long int);
 
 	int  vfo;  // 0, 1 or 2.  = A, B or Memory                 wbx2
 
