@@ -52,6 +52,7 @@
 #include <FL/Fl_Input_Choice.H>
 
 #include "flinput2.h"
+#include "flbrowser2.h"
 #include "Fl_SigBar.h"
 #include "FreqControl.h"
 #include "combo.h"
@@ -159,6 +160,9 @@ extern Fl_Light_Button *btnVol;
 extern Fl_Wheel_Value_Slider *sldrVOLUME;
 extern Fl_Group *grpTABS;
 
+// wide UI group exposure
+extern Fl_Group *grp_row1b1b;
+
 extern Fl_Tabs *tabsGeneric;
 extern Fl_Group *hidden_tabs;
 extern Fl_Group *tab_yaesu_bands;
@@ -175,6 +179,23 @@ extern Fl_Button *btn_yaesu_select_10;
 extern Fl_Button *btn_yaesu_select_11;
 extern Fl_ComboBox *op_yaesu_select60;
 
+extern Fl_Group  *tab_ft991_bands;
+extern Fl_Button *btn_ft991_select_1;
+extern Fl_Button *btn_ft991_select_2;
+extern Fl_Button *btn_ft991_select_3;
+extern Fl_Button *btn_ft991_select_4;
+extern Fl_Button *btn_ft991_select_5;
+extern Fl_Button *btn_ft991_select_6;
+extern Fl_Button *btn_ft991_select_7;
+extern Fl_Button *btn_ft991_select_8;
+extern Fl_Button *btn_ft991_select_9;
+extern Fl_Button *btn_ft991_select_10;
+extern Fl_Button *btn_ft991_select_11;
+extern Fl_Button *btn_ft991_select_12;
+extern Fl_Button *btn_ft991_select_13;
+extern Fl_PL_tone *choice_ft991_tTONE;
+extern Fl_PL_tone *choice_ft991_rTONE;
+
 extern Fl_Group *tab_FT8n_bands;
 extern Fl_Button *btn_FT8n_select_1;
 extern Fl_Button *btn_FT8n_select_2;
@@ -254,6 +275,16 @@ extern Fl_Button *btnUser14;
 extern Fl_Button *btnUser15;
 extern Fl_Button *btnUser16;
 
+extern Fl_Group  *genericUser_3;
+extern Fl_Button *btnUser17;
+extern Fl_Button *btnUser18;
+extern Fl_Button *btnUser19;
+extern Fl_Button *btnUser20;
+extern Fl_Button *btnUser21;
+extern Fl_Button *btnUser22;
+extern Fl_Button *btnUser23;
+extern Fl_Button *btnUser24;
+
 extern Hspinner *spnr_cw_spot_tone;
 extern Hspinner *spnr_cw_qsk;
 extern Hspinner *spnr_cw_weight;
@@ -396,7 +427,7 @@ extern Fl_Button *btnPickFreq;
 extern Fl_Button *btnDelFreq;
 extern Fl_Button *btnClearList;
 
-extern Fl_Browser *FreqSelect;
+extern Fl_Browser2 *FreqSelect;
 
 extern Fl_Input *inAlphaTag;
 
@@ -502,6 +533,7 @@ extern Fl_Value_Input *poll_split;
 extern Fl_Value_Input *poll_noise;
 extern Fl_Value_Input *poll_nr;
 extern Fl_Value_Input *poll_compression;
+extern Fl_Value_Input *poll_ptt;
 extern Fl_Button *btnClearAddControls;
 extern Fl_Value_Input *poll_all;
 extern Fl_Button *btnSetAllAdd;
