@@ -15,7 +15,7 @@
 // GNU General Public License for more details.
 //
 // You should have received a copy of the GNU General Public License
-// along with this program.  If not, see <http://www.gnu.org/licenses/>.
+// aunsigned long int with this program.  If not, see <http://www.gnu.org/licenses/>.
 // ----------------------------------------------------------------------------
 
 #include "FT890.h"
@@ -198,12 +198,12 @@ bool RIG_FT890::get_info()
 	return false;
 }
 
-long RIG_FT890::get_vfoA ()
+unsigned long int RIG_FT890::get_vfoA ()
 {
 	return A.freq;
 }
 
-void RIG_FT890::set_vfoA (long freq)
+void RIG_FT890::set_vfoA (unsigned long int freq)
 {
 	A.freq = freq;
 	freq /=10; // 890 does not support 1 Hz resolution
@@ -228,12 +228,12 @@ void RIG_FT890::set_modeA(int val)
 	showresp(WARN, HEX, "set mode A", cmd, replystr);
 }
 
-long RIG_FT890::get_vfoB()
+unsigned long int RIG_FT890::get_vfoB()
 {
 	return B.freq;
 }
 
-void RIG_FT890::set_vfoB(long freq)
+void RIG_FT890::set_vfoB(unsigned long int freq)
 {
 	B.freq = freq;
 	freq /=10; // 890 does not support 1 Hz resolution
