@@ -22,7 +22,7 @@
 // GNU General Public License for more details.
 //
 // You should have received a copy of the GNU General Public License
-// along with this program.  If not, see <http://www.gnu.org/licenses/>.
+// aunsigned long int with this program.  If not, see <http://www.gnu.org/licenses/>.
 // ----------------------------------------------------------------------------
 
 #include "FT900.h"
@@ -256,12 +256,12 @@ bool RIG_FT900::get_info()
 	return false;
 }
 
-long RIG_FT900::get_vfoA ()
+unsigned long int RIG_FT900::get_vfoA ()
 {
 	return A.freq;
 }
 
-void RIG_FT900::set_vfoA (long freq)
+void RIG_FT900::set_vfoA (unsigned long int freq)
 {
 	A.freq = freq;
 	freq /=10; // FT-900 does not support 1 Hz resolution
@@ -286,12 +286,12 @@ void RIG_FT900::set_modeA(int val)
 	showresp(WARN, HEX, "set mode A", cmd, replystr);
 }
 
-long RIG_FT900::get_vfoB()
+unsigned long int RIG_FT900::get_vfoB()
 {
 	return B.freq;
 }
 
-void RIG_FT900::set_vfoB(long freq)
+void RIG_FT900::set_vfoB(unsigned long int freq)
 {
 	B.freq = freq;
 	freq /=10; // FT-900 does not support 1 Hz resolution
