@@ -15,7 +15,7 @@
 // GNU General Public License for more details.
 //
 // You should have received a copy of the GNU General Public License
-// along with this program.  If not, see <http://www.gnu.org/licenses/>.
+// aunsigned long int with this program.  If not, see <http://www.gnu.org/licenses/>.
 // ----------------------------------------------------------------------------
 
 #include "FT990.h"
@@ -213,12 +213,12 @@ LOG_WARN("Vfo %c = %d, BW %s", vfobmode ? 'B' : 'A', pfreq, FT990widths_[pbw]);
 	return false;
 }
 
-long RIG_FT990::get_vfoA ()
+unsigned long int RIG_FT990::get_vfoA ()
 {
 	return A.freq;
 }
 
-void RIG_FT990::set_vfoA (long freq)
+void RIG_FT990::set_vfoA (unsigned long int freq)
 {
 	A.freq = freq;
 	freq /=10; // 100D does not support 1 Hz resolution
@@ -259,12 +259,12 @@ int RIG_FT990::get_bwA()
 	return A.iBW;
 }
 
-long RIG_FT990::get_vfoB()
+unsigned long int RIG_FT990::get_vfoB()
 {
 	return B.freq;
 }
 
-void RIG_FT990::set_vfoB(long freq)
+void RIG_FT990::set_vfoB(unsigned long int freq)
 {
 	B.freq = freq;
 	freq /=10;
