@@ -23,7 +23,7 @@
 #include "debug.h"
 #include "support.h"
 
-#define FL991A_WAIT_TIME 100
+#define FL991A_WAIT_TIME 200
 
 enum mFT991 {
   mLSB, mUSB, mCW, mFM, mAM, mRTTY_L, mCW_R, mPKT_L, mRTTY_U, mPKT_FM, mFM_N, mPKT_U, mAM_N, mC4FM };
@@ -396,31 +396,32 @@ void RIG_FT991A::set_split(bool val)
 int RIG_FT991A::get_split()
 {
 	size_t p;
-	int split = 0;
 	char rx, tx;
 // tx vfo
-	cmd = rsp = "FT";
+	cmd = rsp = "RI6";
 	cmd.append(";");
-	wait_char(';',4, FL991A_WAIT_TIME, "get split tx vfo", ASC);
+	wait_char(';', 5, FL991A_WAIT_TIME, "get split tx vfo", ASC);
 	gett("get split tx");
 
 	p = replystr.rfind(rsp);
 	if (p == string::npos) return false;
-	tx = replystr[p+2] - '0';
+	tx = replystr[p+3] - '0';
 
 // rx vfo
-	cmd = rsp = "FR";
+// The FT991/A doesn't support FR so use RI7
+// Radio Information -> VFO-A RX -> 0 : 1
+	cmd = rsp = "RI7";
 	cmd.append(";");
-	wait_char(';',4, FL991A_WAIT_TIME, "get split rx vfo", ASC);
+	wait_char(';', 5, FL991A_WAIT_TIME, "get split rx vfo", ASC);
 	gett("get split rx");
 
 	p = replystr.rfind(rsp);
 	if (p == string::npos) return false;
-	rx = replystr[p+2] - '0';
+	rx = replystr[p+3] - '0';
 
-	split = (tx == 1 ? 2 : 0) + (rx >= 4 ? 1 : 0);
-
-	return split;
+	// If tx & rx are different: not running split
+	if (tx == rx) return true;
+	return false;
 }
 
 
@@ -547,6 +548,7 @@ void RIG_FT991A::set_PTT_control(int val)
 {
 	cmd = val ? "TX1;" : "TX0;";
 	sendCommand(cmd);
+	MilliSleep(50);
 	showresp(WARN, ASC, "SET PTT", cmd, replystr);
 	ptt_ = val;
 	sett("set_ptt_control");
@@ -1108,7 +1110,6 @@ int RIG_FT991A::get_noise()
 void RIG_FT991A::set_mic_gain(int val)
 {
 	cmd = "MG000;";
-	val = (int)(val * 2.50);
 	for (int i = 3; i > 0; i--) {
 		cmd[1+i] += val % 10;
 		val /= 10;
@@ -1128,9 +1129,8 @@ int RIG_FT991A::get_mic_gain()
 	size_t p = replystr.rfind(rsp);
 	if (p == string::npos) return progStatus.mic_gain;
 	int val = atoi(&replystr[p+2]);
-	val = (int)(val / 2.50);
 	if (val > 100) val = 100;
-	return ceil(val);
+	return val;
 }
 
 void RIG_FT991A::get_mic_min_max_step(int &min, int &max, int &step)
