@@ -15,7 +15,7 @@
 // GNU General Public License for more details.
 //
 // You should have received a copy of the GNU General Public License
-// along with this program.  If not, see <http://www.gnu.org/licenses/>.
+// aunsigned long int with this program.  If not, see <http://www.gnu.org/licenses/>.
 // ----------------------------------------------------------------------------
 
 #include <iostream>
@@ -223,7 +223,7 @@ void RIG_FTdx1200::initialize()
 // Disable Auto Information mode
 	sendCommand("AI0;");
 
-// "MRnnn;" if valid, returns last channel used, "mrlll...;", along with channel nnn info.
+// "MRnnn;" if valid, returns last channel used, "mrlll...;", aunsigned long int with channel nnn info.
 	cmd = "MR118;";
 	wait_char(';', 27, 100, "Read UK 60m Channel Mem", ASC);
 	size_t p = replystr.rfind("MR");
@@ -271,7 +271,7 @@ bool RIG_FTdx1200::check ()
 	return false;
 }
 
-long RIG_FTdx1200::get_vfoA ()
+unsigned long int RIG_FTdx1200::get_vfoA ()
 {
 	cmd = "FA;";
 	rsp = "FA";
@@ -288,7 +288,7 @@ long RIG_FTdx1200::get_vfoA ()
 	return freqA;
 }
 
-void RIG_FTdx1200::set_vfoA (long freq)
+void RIG_FTdx1200::set_vfoA (unsigned long int freq)
 {
 	freqA = freq;
 	cmd = "FA00000000;";
@@ -301,7 +301,7 @@ void RIG_FTdx1200::set_vfoA (long freq)
 	set_trace(3,"set_vfoA", cmd.c_str(), replystr.c_str());
 }
 
-long RIG_FTdx1200::get_vfoB ()
+unsigned long int RIG_FTdx1200::get_vfoB ()
 {
 	cmd = "FB;";
 	rsp = "FB";
@@ -319,7 +319,7 @@ long RIG_FTdx1200::get_vfoB ()
 }
 
 
-void RIG_FTdx1200::set_vfoB (long freq)
+void RIG_FTdx1200::set_vfoB (unsigned long int freq)
 {
 	freqB = freq;
 	cmd = "FB00000000;";
@@ -641,7 +641,7 @@ void RIG_FTdx1200::tune_rig(int)
 	static int rmd = modeA;
 	static int rbw = bwA;
 	static int rpwr = 100;
-	static long rfreq = freqA;	// fix for menu 047 OFSt default
+	static unsigned long int rfreq = freqA;	// fix for menu 047 OFSt default
 	int use_int_tuner = true;
 
 //  On-The-Fly bandstack by bandstack int/ext tuner
