@@ -15,7 +15,7 @@
 // GNU General Public License for more details.
 //
 // You should have received a copy of the GNU General Public License
-// along with this program.  If not, see <http://www.gnu.org/licenses/>.
+// aunsigned long int with this program.  If not, see <http://www.gnu.org/licenses/>.
 // ----------------------------------------------------------------------------
 
 #include <iostream>
@@ -284,7 +284,7 @@ bool RIG_FTdx9000::check ()
 	return false;
 }
 
-long RIG_FTdx9000::get_vfoA ()
+unsigned long int RIG_FTdx9000::get_vfoA ()
 {
 	cmd = rsp = "FA";
 	cmd += ';';
@@ -301,7 +301,7 @@ long RIG_FTdx9000::get_vfoA ()
 	return freqA;
 }
 
-void RIG_FTdx9000::set_vfoA (long freq)
+void RIG_FTdx9000::set_vfoA (unsigned long int freq)
 {
 	freqA = freq;
 	cmd = "FA00000000;";
@@ -313,7 +313,7 @@ void RIG_FTdx9000::set_vfoA (long freq)
 	showresp(WARN, ASC, "SET vfo A", cmd, replystr);
 }
 
-long RIG_FTdx9000::get_vfoB ()
+unsigned long int RIG_FTdx9000::get_vfoB ()
 {
 	cmd = rsp = "FB";
 	cmd += ';';
@@ -331,7 +331,7 @@ long RIG_FTdx9000::get_vfoB ()
 }
 
 
-void RIG_FTdx9000::set_vfoB (long freq)
+void RIG_FTdx9000::set_vfoB (unsigned long int freq)
 {
 	freqB = freq;
 	cmd = "FB00000000;";
