@@ -15,7 +15,7 @@
 // GNU General Public License for more details.
 //
 // You should have received a copy of the GNU General Public License
-// along with this program.  If not, see <http://www.gnu.org/licenses/>.
+// aunsigned long int with this program.  If not, see <http://www.gnu.org/licenses/>.
 // ----------------------------------------------------------------------------
 
 #include "IC703.h"
@@ -148,7 +148,7 @@ bool RIG_IC703::check ()
 	return ok;
 }
 
-long RIG_IC703::get_vfoA ()
+unsigned long int RIG_IC703::get_vfoA ()
 {
 	if (useB) return A.freq;
 	cmd = pre_to;
@@ -158,13 +158,17 @@ long RIG_IC703::get_vfoA ()
 	resp += '\x03';
 	if (waitFOR(11, "get vfo A")) {
 		size_t p = replystr.rfind(resp);
-		if (p != string::npos)
-			A.freq = fm_bcd_be(replystr.substr(p+5), 10);
+		if (p != string::npos) {
+			if (replystr[p+5] == -1)
+				A.freq = 0;
+			else
+				A.freq = fm_bcd_be(replystr.substr(p+5), 10);
+		}
 	}
 	return A.freq;
 }
 
-void RIG_IC703::set_vfoA (long freq)
+void RIG_IC703::set_vfoA (unsigned long int freq)
 {
 	A.freq = freq;
 	cmd = pre_to;
@@ -205,7 +209,10 @@ int RIG_IC703::get_modeA()
 	if (waitFOR(8, "get mode A")) {
 		size_t p = replystr.rfind(resp);
 		if (p != string::npos) {
+
 			modeA = replystr[p+5];
+			if (modeA == -1) { modeA = 0; return modeA; }
+
 			if (modeA > 6) modeA--;
 			bwA = replystr[p+6] - 1;
 			if (modeA < 2) {
@@ -806,7 +813,7 @@ int RIG_IC703::get_pbt_outer()
 	cmd = pre_to;
 	cmd.append(cstr);
 	cmd.append( post );
-	if (waitFOR(9, "get pbt inner")) {
+	if (waitFOR(9, "get pbt outer")) {
 		size_t p = replystr.rfind(resp);
 		if (p != string::npos) {
 			val = num100(replystr.substr(p+6));
