@@ -15,7 +15,7 @@
 // GNU General Public License for more details.
 //
 // You should have received a copy of the GNU General Public License
-// along with this program.  If not, see <http://www.gnu.org/licenses/>.
+// aunsigned long int with this program.  If not, see <http://www.gnu.org/licenses/>.
 // ----------------------------------------------------------------------------
 
 #include "IC718.h"
@@ -140,7 +140,7 @@ bool RIG_IC718::check ()
 	return ok;
 }
 
-long RIG_IC718::get_vfoA ()
+unsigned long int RIG_IC718::get_vfoA ()
 {
 	if (useB) return A.freq;
 	cmd = pre_to;
@@ -150,13 +150,17 @@ long RIG_IC718::get_vfoA ()
 	resp += '\x03';
 	if (waitFOR(11, "get vfo A")) {
 		size_t p = replystr.rfind(resp);
-		if (p != string::npos)
-			A.freq = fm_bcd_be(replystr.substr(p+5), 10);
+		if (p != string::npos) {
+			if (replystr[p+5] == -1)
+				A.freq = 0;
+			else
+				A.freq = fm_bcd_be(replystr.substr(p+5), 10);
+		}
 	}
 	return A.freq;
 }
 
-void RIG_IC718::set_vfoA (long freq)
+void RIG_IC718::set_vfoA (unsigned long int freq)
 {
 	A.freq = freq;
 	cmd = pre_to;
@@ -166,7 +170,7 @@ void RIG_IC718::set_vfoA (long freq)
 	waitFB("set vfo A");
 }
 
-long RIG_IC718::get_vfoB ()
+unsigned long int RIG_IC718::get_vfoB ()
 {
 	if (!useB) return B.freq;
 	string resp = pre_fm;
@@ -176,13 +180,17 @@ long RIG_IC718::get_vfoB ()
 	cmd.append( post );
 	if (waitFOR(11, "get vfo B")) {
 		size_t p = replystr.rfind(resp);
-		if (p != string::npos)
-			B.freq = fm_bcd_be(replystr.substr(p+5), 10);
+		if (p != string::npos) {
+			if (replystr[p+5] == -1)
+				A.freq = 0;
+			else
+				B.freq = fm_bcd_be(replystr.substr(p+5), 10);
+		}
 	}
 	return B.freq;
 }
 
-void RIG_IC718::set_vfoB (long freq)
+void RIG_IC718::set_vfoB (unsigned long int freq)
 {
 	B.freq = freq;
 	cmd = pre_to;
@@ -485,6 +493,7 @@ int RIG_IC718::get_modeA()
 	if (waitFOR(8, "get modeA")) {
 		size_t p = replystr.rfind(resp);
 		if (p != string::npos) {
+			if (replystr[p+5] == -1) { modeA = filA = 0; return modeA; }
 			modeA = replystr[p+5];
 			if (modeA > 6) modeA -= 2;
 			filter_nbr = replystr[p+6];
@@ -514,6 +523,7 @@ int RIG_IC718::get_modeB()
 	if (waitFOR(8, "get modeB")) {
 		size_t p = replystr.rfind(resp);
 		if (p != string::npos) {
+			if (replystr[p+5] == -1) { modeB = filB = 0; return modeB; }
 			modeB = replystr[p+5];
 			if (modeB > 6) modeB -= 2;
 			filter_nbr = replystr[p+6];
