@@ -15,7 +15,7 @@
 // GNU General Public License for more details.
 //
 // You should have received a copy of the GNU General Public License
-// along with this program.  If not, see <http://www.gnu.org/licenses/>.
+// aunsigned long int with this program.  If not, see <http://www.gnu.org/licenses/>.
 // ----------------------------------------------------------------------------
 #include <iostream>
 #include <sstream>
@@ -265,7 +265,7 @@ bool RIG_IC7200::check ()
 	return ok;
 }
 
-long RIG_IC7200::get_vfoA ()
+unsigned long int RIG_IC7200::get_vfoA ()
 {
 	if (useB) return A.freq;
 	string resp = pre_fm;
@@ -275,14 +275,18 @@ long RIG_IC7200::get_vfoA ()
 	cmd.append( post );
 	if (waitFOR(11, "get vfo A")) {
 		size_t p = replystr.rfind(resp);
-		if (p != string::npos)
-			A.freq = fm_bcd_be(replystr.substr(p+5), 10);
+		if (p != string::npos) {
+			if (replystr[p+5] == -1)
+				A.freq = 0;
+			else
+				A.freq = fm_bcd_be(replystr.substr(p+5), 10);
+		}
 	}
 	get_trace(2, "get_vfoA()", str2hex(replystr.c_str(), replystr.length()));
 	return A.freq;
 }
 
-void RIG_IC7200::set_vfoA (long freq)
+void RIG_IC7200::set_vfoA (unsigned long int freq)
 {
 	A.freq = freq;
 	cmd = pre_to;
@@ -293,7 +297,7 @@ void RIG_IC7200::set_vfoA (long freq)
 	waitFB("set vfo A");
 }
 
-long RIG_IC7200::get_vfoB ()
+unsigned long int RIG_IC7200::get_vfoB ()
 {
 	if (!useB) return B.freq;
 	string resp = pre_fm;
@@ -303,14 +307,18 @@ long RIG_IC7200::get_vfoB ()
 	cmd.append( post );
 	if (waitFOR(11, "get vfo B")) {
 		size_t p = replystr.rfind(resp);
-		if (p != string::npos)
-			B.freq = fm_bcd_be(replystr.substr(p+5), 10);
+		if (p != string::npos) {
+			if (replystr[p+5] == -1)
+				A.freq = 0;
+			else
+				B.freq = fm_bcd_be(replystr.substr(p+5), 10);
+		}
 	}
 	get_trace(2, "get_vfoB()", str2hex(replystr.c_str(), replystr.length()));
 	return B.freq;
 }
 
-void RIG_IC7200::set_vfoB (long freq)
+void RIG_IC7200::set_vfoB (unsigned long int freq)
 {
 	B.freq = freq;
 	cmd = pre_to;
@@ -871,9 +879,12 @@ int RIG_IC7200::get_modeA()
 	if (waitFOR(8, "get mode A")) {
 		p = replystr.rfind(resp);
 		if (p != string::npos) {
-			md = replystr[p + 5];
-			if (md > 6) md -= 2;
-			A.filter = replystr[p+6];
+			if (replystr[p+5] == -1) { md = A.filter = 0; }
+			else {
+				md = replystr[p + 5];
+				if (md > 6) md -= 2;
+				A.filter = replystr[p+6];
+			}
 		}
 	}
 	get_trace(2, "get_modeA()", str2hex(replystr.c_str(), replystr.length()));
@@ -899,7 +910,7 @@ int RIG_IC7200::get_modeA()
 	get_trace(4, "mode_filterA[", IC7200modes_[md], "] = ", szfilter[A.filter-1]);
 
 	if (A.imode == CW7200 || A.imode == CWR7200) {
-		cmd.assign(pre_to).append("\x1A\x03\x37");
+		cmd.assign(pre_to).append("\x1A\x03\x37").append(post);
 		resp.assign(pre_fm).append("\x1A\x03\x37");
 		if (waitFOR(9, "get CW sideband")) {
 			p = replystr.rfind(resp);
@@ -951,9 +962,12 @@ int RIG_IC7200::get_modeB()
 	if (waitFOR(8, "get mode B")) {
 		p = replystr.rfind(resp);
 		if (p != string::npos) {
-			md = replystr[p+5];
-			if (md > 6) md -= 2;
-			B.filter = replystr[p+6];
+			if (replystr[p+5] == -1) { md = B.filter = 0; }
+			else {
+				md = replystr[p+5];
+				if (md > 6) md -= 2;
+				B.filter = replystr[p+6];
+			}
 		}
 	}
 	get_trace(2, "get_modeB()", str2hex(replystr.c_str(), replystr.length()));
@@ -979,7 +993,7 @@ int RIG_IC7200::get_modeB()
 	get_trace(4, "mode_filterB[", IC7200modes_[md], "] = ", szfilter[B.filter-1]);
 
 	if (B.imode == CW7200 || B.imode == CWR7200) {
-		cmd.assign(pre_to).append("\x1A\x03\x37");
+		cmd.assign(pre_to).append("\x1A\x03\x37").append(post);
 		resp.assign(pre_fm).append("\x1A\x03\x37");
 		if (waitFOR(9, "get CW sideband")) {
 			p = replystr.rfind(resp);
@@ -1392,8 +1406,6 @@ void RIG_IC7200::set_vox_onoff()
 	set_trace(2, "set_vox_on_off()", str2hex(cmd.c_str(), cmd.length()));
 }
 
-static bool IC7200_notchon = false;
-
 void RIG_IC7200::set_notch(bool on, int freq)
 {
 	int hexval;
@@ -1638,7 +1650,7 @@ int RIG_IC7200::get_pbt_outer()
 	cmd = pre_to;
 	cmd.append(cstr);
 	cmd.append( post );
-	if (waitFOR(9, "get pbt inner")) {
+	if (waitFOR(9, "get pbt outer")) {
 		size_t p = replystr.rfind(resp);
 		if (p != string::npos) {
 			val = num100(replystr.substr(p+6));
@@ -1770,7 +1782,7 @@ void RIG_IC7200::get_band_selection(int v)
 		std::string ans = replystr;
 		size_t p = ans.rfind(pre_fm);
 		if (p != string::npos) {
-			long int bandfreq = fm_bcd_be(ans.substr(p+8, 5), 10);
+			unsigned long int bandfreq = fm_bcd_be(ans.substr(p+8, 5), 10);
 			int bandmode = ans[p+13];
 			int bandfilter = ans[p+14];
 			int banddata = ans[p+15] & 0x10;
@@ -1791,7 +1803,7 @@ void RIG_IC7200::get_band_selection(int v)
 
 void RIG_IC7200::set_band_selection(int v)
 {
-	long freq = (useB ? B.freq : A.freq);
+	unsigned long int freq = (useB ? B.freq : A.freq);
 	int mode = (useB ? B.imode : A.imode);
 	int fil = (useB ? B.filter : A.filter);
 
