@@ -15,7 +15,7 @@
 // GNU General Public License for more details.
 //
 // You should have received a copy of the GNU General Public License
-// along with this program.  If not, see <http://www.gnu.org/licenses/>.
+// aunsigned long int with this program.  If not, see <http://www.gnu.org/licenses/>.
 // ----------------------------------------------------------------------------
 
 #include "IC7410.h"
@@ -239,27 +239,30 @@ int RIG_IC7410::get_modeA()
 	resp += '\x04';
 	if (waitFOR(8, "get mode A")) {
 		size_t p = replystr.rfind(resp);
-		for (md = LSB7410; md <= RTTYR7410; md++)
-			if (replystr[p+5] == IC7410_mode_nbr[md]) break;
-		filA = replystr[p+6];
+		if (replystr[p+5] == -1) { A.imode = filA = 0; }
+		else {
+			for (md = LSB7410; md <= RTTYR7410; md++)
+				if (replystr[p+5] == IC7410_mode_nbr[md]) break;
+			filA = replystr[p+6];
 
-		if (md == LSB7410 || md == USB7410 || md == FM7410) {
-			cmd = pre_to;
-			cmd.append("\x1a\x06");
-			cmd.append(post);
-			resp = pre_fm;
-			resp.append("\x1a\x06");
-			if (waitFOR(9, "get digital setting")) {
-				size_t p = replystr.rfind(resp);
-				if (replystr[p+6] == 0x01) {
-					if (md == LSB7410) md = LSBD7410;
-					else if (md == USB7410) md = USBD7410;
-					else if (md == FM7410) md = FMD7410;
+			if (md == LSB7410 || md == USB7410 || md == FM7410) {
+				cmd = pre_to;
+				cmd.append("\x1a\x06");
+				cmd.append(post);
+				resp = pre_fm;
+				resp.append("\x1a\x06");
+				if (waitFOR(9, "get digital setting")) {
+					size_t p = replystr.rfind(resp);
+					if (replystr[p+6] == 0x01) {
+						if (md == LSB7410) md = LSBD7410;
+						else if (md == USB7410) md = USBD7410;
+						else if (md == FM7410) md = FMD7410;
+					}
+					if (replystr[p+7]) filA = replystr[p+7];
 				}
-				if (replystr[p+7]) filA = replystr[p+7];
 			}
+			A.imode = md;
 		}
-		A.imode = md;
 	}
 	return A.imode;
 }
@@ -293,27 +296,31 @@ int RIG_IC7410::get_modeB()
 	resp += '\x04';
 	if (waitFOR(8, "get mode B")) {
 		size_t p = replystr.rfind(resp);
-		for (md = LSB7410; md <= RTTYR7410; md++)
-			if (replystr[p+5] == IC7410_mode_nbr[md]) break;
-		filA = replystr[p+6];
 
-		if (md == USB7410 || md == AM7410 || md == FM7410) {
-			cmd = pre_to;
-			cmd.append("\x1a\x06");
-			cmd.append(post);
-			resp = pre_fm;
-			resp.append("\x1a\x06");
-			if (waitFOR(9, "get digital")) {
-				size_t p = replystr.rfind(resp);
-				if (replystr[p+6] == 0x01) {
-					if (md == LSB7410) md = LSBD7410;
-					else if (md == USB7410) md = USBD7410;
-					else if (md == FM7410) md = FMD7410;
+		if (replystr[p+5] == -1) { B.imode = filB = 0; }
+		else {
+			for (md = LSB7410; md <= RTTYR7410; md++)
+				if (replystr[p+5] == IC7410_mode_nbr[md]) break;
+			filB = replystr[p+6];
+
+			if (md == USB7410 || md == AM7410 || md == FM7410) {
+				cmd = pre_to;
+				cmd.append("\x1a\x06");
+				cmd.append(post);
+				resp = pre_fm;
+				resp.append("\x1a\x06");
+				if (waitFOR(9, "get digital")) {
+					size_t p = replystr.rfind(resp);
+					if (replystr[p+6] == 0x01) {
+						if (md == LSB7410) md = LSBD7410;
+						else if (md == USB7410) md = USBD7410;
+						else if (md == FM7410) md = FMD7410;
+					}
+					if (replystr[p+7]) filB = replystr[p+7];
 				}
-				if (replystr[p+7]) filB = replystr[p+7];
 			}
+			B.imode = md;
 		}
-		B.imode = md;
 	}
 	return B.imode;
 }
@@ -659,7 +666,7 @@ int RIG_IC7410::get_pbt_outer()
 	cmd = pre_to;
 	cmd.append(cstr);
 	cmd.append( post );
-	if (waitFOR(9, "get pbt inner")) {
+	if (waitFOR(9, "get pbt outer")) {
 		size_t p = replystr.rfind(resp);
 		if (p != string::npos) {
 			val = num100(replystr.substr(p+6));
@@ -737,7 +744,7 @@ void RIG_IC7410::get_band_selection(int v)
 		set_trace(2, "get band stack", str2hex(replystr.c_str(), replystr.length()));
 		size_t p = replystr.rfind(pre_fm);
 		if (p != string::npos) {
-			long int bandfreq = fm_bcd_be(replystr.substr(p+8, 5), 10);
+			unsigned long int bandfreq = fm_bcd_be(replystr.substr(p+8, 5), 10);
 			int bandmode = replystr[p+13];
 			int bandfilter = replystr[p+14];
 			int banddata = replystr[p+15] & 0x10;
@@ -769,7 +776,7 @@ void RIG_IC7410::get_band_selection(int v)
 
 void RIG_IC7410::set_band_selection(int v)
 {
-	long freq = (useB ? B.freq : A.freq);
+	unsigned long int freq = (useB ? B.freq : A.freq);
 	int fil = (useB ? filB : filA);
 	int mode = (useB ? B.imode : A.imode);
 
