@@ -15,7 +15,7 @@
 // GNU General Public License for more details.
 //
 // You should have received a copy of the GNU General Public License
-// along with this program.  If not, see <http://www.gnu.org/licenses/>.
+// aunsigned long int with this program.  If not, see <http://www.gnu.org/licenses/>.
 // ---------------------------------------------------------------------
 
 #include <string>
@@ -197,7 +197,7 @@ int RIG_IC756::get_pbt_outer()
 	cmd = pre_to;
 	cmd.append(cstr);
 	cmd.append( post );
-	if (waitFOR(9, "get pbt inner")) {
+	if (waitFOR(9, "get pbt outer")) {
 		size_t p = replystr.rfind(resp);
 		if (p != string::npos) {
 			val = num100(replystr.substr(p+6));
@@ -397,7 +397,7 @@ bool RIG_IC756PRO::check ()
 	return ok;
 }
 
-long RIG_IC756PRO::get_vfoA ()
+unsigned long int RIG_IC756PRO::get_vfoA ()
 {
 	if (useB) return A.freq;
 	string cstr = "\x03";
@@ -408,13 +408,17 @@ long RIG_IC756PRO::get_vfoA ()
 	cmd.append(post);
 	if (waitFOR(11, "get vfo A")) {
 		size_t p = replystr.rfind(resp);
-		if (p != string::npos)
-			A.freq = fm_bcd_be(replystr.substr(p+5), 10);
+		if (p != string::npos) {
+			if (replystr[p+5] == -1)
+				A.freq = 0;
+			else
+				A.freq = fm_bcd_be(replystr.substr(p+5), 10);
+		}
 	}
 	return A.freq;
 }
 
-void RIG_IC756PRO::set_vfoA (long freq)
+void RIG_IC756PRO::set_vfoA (unsigned long int freq)
 {
 	A.freq = freq;
 	cmd = pre_to;
@@ -424,7 +428,7 @@ void RIG_IC756PRO::set_vfoA (long freq)
 	waitFB("set vfo A");
 }
 
-long RIG_IC756PRO::get_vfoB ()
+unsigned long int RIG_IC756PRO::get_vfoB ()
 {
 	if (!useB) return B.freq;
 	string cstr = "\x03";
@@ -435,13 +439,17 @@ long RIG_IC756PRO::get_vfoB ()
 	cmd.append(post);
 	if (waitFOR(11, "get vfo B")) {
 		size_t p = replystr.rfind(resp);
-		if (p != string::npos)
-			B.freq = fm_bcd_be(replystr.substr(p+5), 10);
+		if (p != string::npos) {
+			if (replystr[p+5] == -1)
+				A.freq = 0;
+			else
+				B.freq = fm_bcd_be(replystr.substr(p+5), 10);
+		}
 	}
 	return B.freq;
 }
 
-void RIG_IC756PRO::set_vfoB (long freq)
+void RIG_IC756PRO::set_vfoB (unsigned long int freq)
 {
 	B.freq = freq;
 	cmd = pre_to;
@@ -720,7 +728,7 @@ int RIG_IC756PRO::get_pbt_outer()
 	cmd = pre_to;
 	cmd.append(cstr);
 	cmd.append( post );
-	if (waitFOR(9, "get pbt inner")) {
+	if (waitFOR(9, "get pbt outer")) {
 		size_t p = replystr.rfind(resp);
 		if (p != string::npos) {
 			val = num100(replystr.substr(p+6));
@@ -839,10 +847,13 @@ int RIG_IC756PRO::get_modeA()
 	if (waitFOR(8, "get mode A")) {
 		size_t p = replystr.rfind(resp);
 		if (p != string::npos) {
-			md = replystr[p+5];
-			if (md > 6) md--;
-			A.imode = md;
-			mf = replystr[p+6];
+			if (replystr[p+5] == -1) { A.imode = mf = 0; }
+			else {
+				md = replystr[p+5];
+				if (md > 6) md--;
+				A.imode = md;
+				mf = replystr[p+6];
+			}
 		}
 	}
 	if (mf > 0 && mf < 4)
@@ -879,10 +890,13 @@ int RIG_IC756PRO::get_modeB()
 	if (waitFOR(8, "get mode B")) {
 		size_t p = replystr.rfind(resp);
 		if (p != string::npos) {
-			md = replystr[p+5];
-			if (md > 6) md--;
-			B.imode = md;
-			mf = replystr[p+6];
+			if (replystr[p+5] == -1) { B.imode = mf = 0; }
+			else {
+				md = replystr[p+5];
+				if (md > 6) md--;
+				B.imode = md;
+				mf = replystr[p+6];
+			}
 		}
 	}
 	if (mf > 0 && mf < 3)
@@ -1416,7 +1430,7 @@ void RIG_IC756PRO::get_band_selection(int v)
 		set_trace(2, "get band stack", str2hex(replystr.c_str(), replystr.length()));
 		size_t p = replystr.rfind(pre_fm);
 		if (p != string::npos) {
-			long int bandfreq = fm_bcd_be(replystr.substr(p+8, 5), 10);
+			unsigned long int bandfreq = fm_bcd_be(replystr.substr(p+8, 5), 10);
 			int bandmode = replystr[p+13];
 			int bandfilter = replystr[p+14];
 			int tone = fm_bcd(replystr.substr(p+16, 3), 6);
@@ -1444,7 +1458,7 @@ void RIG_IC756PRO::get_band_selection(int v)
 
 void RIG_IC756PRO::set_band_selection(int v)
 {
-	long freq = (useB ? B.freq : A.freq);
+	unsigned long int freq = (useB ? B.freq : A.freq);
 	int fil = (useB ? filB : filA);
 	int mode = (useB ? B.imode : A.imode);
 
