@@ -15,7 +15,7 @@
 // GNU General Public License for more details.
 //
 // You should have received a copy of the GNU General Public License
-// along with this program.  If not, see <http://www.gnu.org/licenses/>.
+// aunsigned long int with this program.  If not, see <http://www.gnu.org/licenses/>.
 // ----------------------------------------------------------------------------
 
 #include "IC756PRO2.h"
@@ -211,7 +211,7 @@ bool RIG_IC756PRO2::check ()
 	return ok;
 }
 
-long RIG_IC756PRO2::get_vfoA ()
+unsigned long int RIG_IC756PRO2::get_vfoA ()
 {
 	if (useB) return A.freq;
 	string cstr = "\x03";
@@ -222,14 +222,18 @@ long RIG_IC756PRO2::get_vfoA ()
 	cmd.append(post);
 	if (waitFOR(11, "get vfo A")) {
 		size_t p = replystr.rfind(resp);
-		if (p != string::npos)
-			A.freq = fm_bcd_be(replystr.substr(p+5), 10);
+		if (p != string::npos) {
+			if (replystr[p+5] == -1)
+				A.freq = 0;
+			else
+				A.freq = fm_bcd_be(replystr.substr(p+5), 10);
+		}
 	}
 	get_trace(2, "get_vfoA()", str2hex(replystr.c_str(), replystr.length()));
 	return A.freq;
 }
 
-void RIG_IC756PRO2::set_vfoA (long freq)
+void RIG_IC756PRO2::set_vfoA (unsigned long int freq)
 {
 	A.freq = freq;
 	cmd = pre_to;
@@ -240,7 +244,7 @@ void RIG_IC756PRO2::set_vfoA (long freq)
 	set_trace(2, "set_vfoA()", str2hex(cmd.c_str(), cmd.length()));
 }
 
-long RIG_IC756PRO2::get_vfoB ()
+unsigned long int RIG_IC756PRO2::get_vfoB ()
 {
 	if (!useB) return B.freq;
 	string cstr = "\x03";
@@ -251,14 +255,18 @@ long RIG_IC756PRO2::get_vfoB ()
 	cmd.append(post);
 	if (waitFOR(11, "get vfo B")) {
 		size_t p = replystr.rfind(resp);
-		if (p != string::npos)
-			B.freq = fm_bcd_be(replystr.substr(p+5), 10);
+		if (p != string::npos) {
+			if (replystr[p+5] == -1)
+				A.freq = 0;
+			else
+				B.freq = fm_bcd_be(replystr.substr(p+5), 10);
+		}
 	}
 	get_trace(2, "get_vfoB()", str2hex(replystr.c_str(), replystr.length()));
 	return B.freq;
 }
 
-void RIG_IC756PRO2::set_vfoB (long freq)
+void RIG_IC756PRO2::set_vfoB (unsigned long int freq)
 {
 	B.freq = freq;
 	cmd = pre_to;
@@ -540,7 +548,7 @@ int RIG_IC756PRO2::get_pbt_outer()
 	cmd = pre_to;
 	cmd.append(cstr);
 	cmd.append( post );
-	if (waitFOR(9, "get pbt inner")) {
+	if (waitFOR(9, "get pbt outer")) {
 		size_t p = replystr.rfind(resp);
 		if (p != string::npos) {
 			val = num100(replystr.substr(p+6));
@@ -650,31 +658,34 @@ int RIG_IC756PRO2::get_modeA()
 		get_trace(2, "get_modeA()", str2hex(replystr.c_str(), replystr.length()));
 		size_t p = replystr.rfind(resp);
 		if (p != string::npos) {
-			md = replystr[p+5];
-			if (md > 6) md--;
-			filA = replystr[p+6];
-			cstr = "\x1A\x06";
-			resp = pre_fm;
-			resp.append(cstr);
-			cmd = pre_to;
-			cmd.append(cstr);
-			cmd.append(post);
+			if (replystr[p+5] == -1) { A.imode = filA = 0; }
+			else {
+				md = replystr[p+5];
+				if (md > 6) md--;
+				filA = replystr[p+6];
+				cstr = "\x1A\x06";
+				resp = pre_fm;
+				resp.append(cstr);
+				cmd = pre_to;
+				cmd.append(cstr);
+				cmd.append(post);
 //			replystr = "\xFE\xFE\x64\xE0\x1A\x06\xFD\xFE\xFE\xE0\x64\x1A\x06\x00\xFD"; {
-			if (waitFOR(8, "data ?")) {
-				get_trace(2, "get_data_modeA()", str2hex(replystr.c_str(), replystr.length()));
-				p = replystr.rfind(resp);
-				if (p != string::npos) {
-					if (replystr[p+6]) {
-						switch (md) {
-							case 0 : md = 8; break;
-							case 1 : md = 9; break;
-							case 5 : md = 10; break;
-							default : break;
+				if (waitFOR(8, "data ?")) {
+					get_trace(2, "get_data_modeA()", str2hex(replystr.c_str(), replystr.length()));
+					p = replystr.rfind(resp);
+					if (p != string::npos) {
+						if (replystr[p+6]) {
+							switch (md) {
+								case 0 : md = 8; break;
+								case 1 : md = 9; break;
+								case 5 : md = 10; break;
+								default : break;
+							}
 						}
 					}
 				}
+				A.imode = md;
 			}
-			A.imode = md;
 		}
 	}
 	return A.imode;
@@ -723,30 +734,33 @@ int RIG_IC756PRO2::get_modeB()
 		get_trace(2, "get_modeB()", str2hex(replystr.c_str(), replystr.length()));
 		size_t p = replystr.rfind(resp);
 		if (p != string::npos) {
-			md = replystr[p+5];
-			if (md > 6) md--;
-			filB = replystr[p+6];
-			cstr = "\x1A\x06";
-			resp = pre_fm;
-			resp.append(cstr);
-			cmd = pre_to;
-			cmd.append(cstr);
-			cmd.append(post);
-			if (waitFOR(8, "data ?")) {
-				get_trace(2, "get_data_modeB()", str2hex(replystr.c_str(), replystr.length()));
-				p = replystr.rfind(resp);
-				if (p != string::npos) {
-					if (replystr[p+6]) {
-						switch (md) {
-							case 0 : md = 8; break;
-							case 1 : md = 9; break;
-							case 5 : md = 10; break;
-							default : break;
+			if (replystr[p+5] == -1) { B.imode = filB = 0; }
+			else {
+				md = replystr[p+5];
+				if (md > 6) md--;
+				filB = replystr[p+6];
+				cstr = "\x1A\x06";
+				resp = pre_fm;
+				resp.append(cstr);
+				cmd = pre_to;
+				cmd.append(cstr);
+				cmd.append(post);
+				if (waitFOR(8, "data ?")) {
+					get_trace(2, "get_data_modeB()", str2hex(replystr.c_str(), replystr.length()));
+					p = replystr.rfind(resp);
+					if (p != string::npos) {
+						if (replystr[p+6]) {
+							switch (md) {
+								case 0 : md = 8; break;
+								case 1 : md = 9; break;
+								case 5 : md = 10; break;
+								default : break;
+							}
 						}
 					}
 				}
+				B.imode = md;
 			}
-			B.imode = md;
 		}
 	}
 	return B.imode;
@@ -1175,7 +1189,7 @@ void RIG_IC756PRO2::get_band_selection(int v)
 		set_trace(2, "get band stack", str2hex(replystr.c_str(), replystr.length()));
 		size_t p = replystr.rfind(pre_fm);
 		if (p != string::npos) {
-			long int bandfreq = fm_bcd_be(replystr.substr(p+8, 5), 10);
+			unsigned long int bandfreq = fm_bcd_be(replystr.substr(p+8, 5), 10);
 			int bandmode = replystr[p+13];
 			int bandfilter = replystr[p+14];
 			int banddata = replystr[p+15] & 0x10;
@@ -1205,7 +1219,7 @@ void RIG_IC756PRO2::get_band_selection(int v)
 
 void RIG_IC756PRO2::set_band_selection(int v)
 {
-	long freq = (useB ? B.freq : A.freq);
+	unsigned long int freq = (useB ? B.freq : A.freq);
 	int fil = (useB ? filB : filA);
 	int mode = (useB ? B.imode : A.imode);
 
