@@ -15,7 +15,7 @@
 // GNU General Public License for more details.
 //
 // You should have received a copy of the GNU General Public License
-// along with this program.  If not, see <http://www.gnu.org/licenses/>.
+// aunsigned long int with this program.  If not, see <http://www.gnu.org/licenses/>.
 // ----------------------------------------------------------------------------
 
 #include "IC756PRO3.h"
@@ -216,7 +216,7 @@ bool RIG_IC756PRO3::check ()
 	return ok;
 }
 
-long RIG_IC756PRO3::get_vfoA ()
+unsigned long int RIG_IC756PRO3::get_vfoA ()
 {
 	if (useB) return A.freq;
 	string cstr = "\x03";
@@ -227,13 +227,17 @@ long RIG_IC756PRO3::get_vfoA ()
 	cmd.append(post);
 	if (waitFOR(11, "get vfo A")) {
 		size_t p = replystr.rfind(resp);
-		if (p != string::npos)
-			A.freq = fm_bcd_be(replystr.substr(p+5), 10);
+		if (p != string::npos) {
+			if (replystr[p+5] == -1)
+				A.freq = 0;
+			else
+				A.freq = fm_bcd_be(replystr.substr(p+5), 10);
+		}
 	}
 	return A.freq;
 }
 
-void RIG_IC756PRO3::set_vfoA (long freq)
+void RIG_IC756PRO3::set_vfoA (unsigned long int freq)
 {
 	A.freq = freq;
 	cmd = pre_to;
@@ -243,7 +247,7 @@ void RIG_IC756PRO3::set_vfoA (long freq)
 	waitFB("set vfo A");
 }
 
-long RIG_IC756PRO3::get_vfoB ()
+unsigned long int RIG_IC756PRO3::get_vfoB ()
 {
 	if (!useB) return B.freq;
 	string cstr = "\x03";
@@ -254,13 +258,17 @@ long RIG_IC756PRO3::get_vfoB ()
 	cmd.append(post);
 	if (waitFOR(11, "get vfo B")) {
 		size_t p = replystr.rfind(resp);
-		if (p != string::npos)
-			B.freq = fm_bcd_be(replystr.substr(p+5), 10);
+		if (p != string::npos) {
+			if (replystr[p+5] == -1)
+				B.freq = 0;
+			else
+				B.freq = fm_bcd_be(replystr.substr(p+5), 10);
+		}
 	}
 	return B.freq;
 }
 
-void RIG_IC756PRO3::set_vfoB (long freq)
+void RIG_IC756PRO3::set_vfoB (unsigned long int freq)
 {
 	B.freq = freq;
 	cmd = pre_to;
@@ -595,7 +603,7 @@ int RIG_IC756PRO3::get_pbt_outer()
 	cmd = pre_to;
 	cmd.append(cstr);
 	cmd.append( post );
-	if (waitFOR(9, "get pbt inner")) {
+	if (waitFOR(9, "get pbt outer")) {
 		size_t p = replystr.rfind(resp);
 		if (p != string::npos) {
 			val = num100(replystr.substr(p+6));
@@ -1035,23 +1043,26 @@ int RIG_IC756PRO3::get_modeA()
 		size_t p = replystr.rfind(resp);
 		if (p != string::npos) {
 			md = replystr[p+5];
-			if (md > 6) md--;
-			filA = replystr[p+6];
-			cstr = "\x1A\x06";
-			resp = pre_fm;
-			resp.append(cstr);
-			cmd = pre_to;
-			cmd.append(cstr);
-			cmd.append(post);
-			if (waitFOR(9, "data mode?")) {
-				p = replystr.rfind(resp);
-				if (p != string::npos) {
-					if (replystr[p+6]) {
-						switch (md) {
-							case 0 : md = 8; break;
-							case 1 : md = 9; break;
-							case 5 : md = 10; break;
-							default : break;
+			if (md == -1) { md = filA = 0; }
+			else {
+				if (md > 6) md--;
+				filA = replystr[p+6];
+				cstr = "\x1A\x06";
+				resp = pre_fm;
+				resp.append(cstr);
+				cmd = pre_to;
+				cmd.append(cstr);
+				cmd.append(post);
+				if (waitFOR(9, "data mode?")) {
+					p = replystr.rfind(resp);
+					if (p != string::npos) {
+						if (replystr[p+6]) {
+							switch (md) {
+								case 0 : md = 8; break;
+								case 1 : md = 9; break;
+								case 5 : md = 10; break;
+								default : break;
+							}
 						}
 					}
 				}
@@ -1101,23 +1112,26 @@ int RIG_IC756PRO3::get_modeB()
 		size_t p = replystr.rfind(resp);
 		if (p != string::npos) {
 			md = replystr[p+5];
-			if (md > 6) md--;
-			filA = replystr[p+6];
-			cstr = "\x1A\x06";
-			resp = pre_fm;
-			resp.append(cstr);
-			cmd = pre_to;
-			cmd.append(cstr);
-			cmd.append(post);
-			if (waitFOR(9, "data mode?")) {
-				p = replystr.rfind(resp);
-				if (p != string::npos) {
-					if (replystr[p+6]) {
-						switch (md) {
-							case 0 : md = 8; break;
-							case 1 : md = 9; break;
-							case 5 : md = 10; break;
-							default : break;
+			if (md == -1) { md = filB = 0; }
+			else {
+				if (md > 6) md--;
+				filB = replystr[p+6];
+				cstr = "\x1A\x06";
+				resp = pre_fm;
+				resp.append(cstr);
+				cmd = pre_to;
+				cmd.append(cstr);
+				cmd.append(post);
+				if (waitFOR(9, "data mode?")) {
+					p = replystr.rfind(resp);
+					if (p != string::npos) {
+						if (replystr[p+6]) {
+							switch (md) {
+								case 0 : md = 8; break;
+								case 1 : md = 9; break;
+								case 5 : md = 10; break;
+								default : break;
+							}
 						}
 					}
 				}
@@ -1224,7 +1238,7 @@ void RIG_IC756PRO3::get_band_selection(int v)
 		set_trace(2, "get band stack", str2hex(replystr.c_str(), replystr.length()));
 		size_t p = replystr.rfind(pre_fm);
 		if (p != string::npos) {
-			long int bandfreq = fm_bcd_be(replystr.substr(p+8, 5), 10);
+			unsigned long int bandfreq = fm_bcd_be(replystr.substr(p+8, 5), 10);
 			int bandmode = replystr[p+13];
 			int bandfilter = replystr[p+14];
 			int banddata = replystr[p+15] & 0x10;
@@ -1254,7 +1268,7 @@ void RIG_IC756PRO3::get_band_selection(int v)
 
 void RIG_IC756PRO3::set_band_selection(int v)
 {
-	long freq = (useB ? B.freq : A.freq);
+	unsigned long int freq = (useB ? B.freq : A.freq);
 	int fil = (useB ? filB : filA);
 	int mode = (useB ? B.imode : A.imode);
 
