@@ -15,7 +15,7 @@
 // GNU General Public License for more details.
 //
 // You should have received a copy of the GNU General Public License
-// along with this program.  If not, see <http://www.gnu.org/licenses/>.
+// aunsigned long int with this program.  If not, see <http://www.gnu.org/licenses/>.
 // ----------------------------------------------------------------------------
 
 #include "IC7600.h"
@@ -244,7 +244,7 @@ bool RIG_IC7600::check ()
 	return ok;
 }
 
-long RIG_IC7600::get_vfoA ()
+unsigned long int RIG_IC7600::get_vfoA ()
 {
 	if (useB) return A.freq;
 	string resp;
@@ -252,14 +252,18 @@ long RIG_IC7600::get_vfoA ()
 	if (waitFOR(11, "get vfo A")) {
 		resp.assign(pre_fm).append("\x03");
 		size_t p = replystr.rfind(resp);
-		if (p != string::npos)
-			A.freq = fm_bcd_be(replystr.substr(p+5), 10);
+		if (p != string::npos) {
+			if (replystr[p+5] == -1)
+				A.freq = 0;
+			else
+				A.freq = fm_bcd_be(replystr.substr(p+5), 10);
+		}
 	}
 	get_trace(2, "get_vfoA()", str2hex(replystr.c_str(), replystr.length()));
 	return A.freq;
 }
 
-void RIG_IC7600::set_vfoA (long freq)
+void RIG_IC7600::set_vfoA (unsigned long int freq)
 {
 	A.freq = freq;
 	cmd.assign(pre_to).append("\x05");
@@ -269,7 +273,7 @@ void RIG_IC7600::set_vfoA (long freq)
 	waitFB("set vfo A");
 }
 
-long RIG_IC7600::get_vfoB ()
+unsigned long int RIG_IC7600::get_vfoB ()
 {
 	if (!useB) return B.freq;
 	string resp = pre_fm;
@@ -277,14 +281,18 @@ long RIG_IC7600::get_vfoB ()
 	if (waitFOR(11, "get vfo B")) {
 		resp.assign(pre_fm).append("\x03");
 		size_t p = replystr.rfind(resp);
-		if (p != string::npos)
-			B.freq = fm_bcd_be(replystr.substr(p+5), 10);
+		if (p != string::npos) {
+			if (replystr[p+5] == -1)
+				A.freq = 0;
+			else
+				B.freq = fm_bcd_be(replystr.substr(p+5), 10);
+		}
 	}
 	get_trace(2, "get_vfoB()", str2hex(replystr.c_str(), replystr.length()));
 	return B.freq;
 }
 
-void RIG_IC7600::set_vfoB (long freq)
+void RIG_IC7600::set_vfoB (unsigned long int freq)
 {
 	B.freq = freq;
 	cmd.assign(pre_to).append("\x05");
@@ -367,25 +375,28 @@ int RIG_IC7600::get_modeA()
 		resp.assign(pre_fm).append("\x04");
 		p = replystr.rfind(resp);
 		if (p == string::npos) return A.imode;
+
+		if (replystr[p+5] == -1) { A.imode = filA = 0; return A.imode; }
+
 		for (md = 0; md < 10; md++) {
 			if (replystr[p+5] == IC7600_mode_nbr[md]) {
 				A.imode = md;
-			}
-		}
-		filA = replystr[p+6];
-		get_trace(2, "get_modeA()", str2hex(replystr.c_str(), replystr.length()));
-		if (A.imode < 2) {
-			cmd.assign(pre_to).append("\x1A\x06").append(post);
-			if (waitFOR(9, "data mode?")) {
-				resp.assign(pre_fm).append("\x1A\x06");
-				p = replystr.rfind(resp);
-				if (p == string::npos) return A.imode;
-				int dmode = replystr[p+6];
-				if(dmode != 0) {
-					if (A.imode == 0) A.imode = 9 + dmode;
-					else if (A.imode == 1) A.imode = 12 + dmode;
+				filA = replystr[p+6];
+				get_trace(2, "get_modeA()", str2hex(replystr.c_str(), replystr.length()));
+				if (A.imode < 2) {
+					cmd.assign(pre_to).append("\x1A\x06").append(post);
+					if (waitFOR(9, "data mode?")) {
+						resp.assign(pre_fm).append("\x1A\x06");
+						p = replystr.rfind(resp);
+						if (p == string::npos) return A.imode;
+						int dmode = replystr[p+6];
+						if(dmode != 0) {
+							if (A.imode == 0) A.imode = 9 + dmode;
+							else if (A.imode == 1) A.imode = 12 + dmode;
+						}
+						get_trace(2, "get_data_modeA()", str2hex(replystr.c_str(), replystr.length()));
+					}
 				}
-				get_trace(2, "get_data_modeA()", str2hex(replystr.c_str(), replystr.length()));
 			}
 		}
 	}
@@ -428,6 +439,9 @@ int RIG_IC7600::get_modeB()
 		resp.assign(pre_fm).append("\x04");
 		p = replystr.rfind(resp);
 		if (p == string::npos) return B.imode;
+
+		if (replystr[p+5] == -1) { B.imode = filB = 0; return B.imode; }
+
 		for (md = 0; md < 10; md++) if (replystr[p+5] == IC7600_mode_nbr[md]) break;
 		if (md == 10) md = 0;
 		B.imode = md;
@@ -440,7 +454,7 @@ int RIG_IC7600::get_modeB()
 				resp.assign(pre_fm).append("\x1A\x06");
 				p = replystr.rfind(resp);
 				if (p == string::npos) return B.imode;
-				int dmode = replystr[p+6];
+				int dmode = replystr[p+6];	
 				if(dmode != 0) {
 					if (B.imode == 0) B.imode = 9 + dmode;
 					else if (B.imode == 1) B.imode = 12 + dmode;
@@ -1379,7 +1393,7 @@ int RIG_IC7600::get_pbt_outer()
 	cmd = pre_to;
 	cmd.append(cstr);
 	cmd.append( post );
-	if (waitFOR(9, "get pbt inner")) {
+	if (waitFOR(9, "get pbt outer")) {
 		size_t p = replystr.rfind(resp);
 		if (p != string::npos) {
 			val = num100(replystr.substr(p+6));
@@ -1457,7 +1471,7 @@ void RIG_IC7600::get_band_selection(int v)
 		set_trace(2, "get band stack", str2hex(replystr.c_str(), replystr.length()));
 		size_t p = replystr.rfind(pre_fm);
 		if (p != string::npos) {
-			long int bandfreq = fm_bcd_be(replystr.substr(p+8, 5), 10);
+			unsigned long int bandfreq = fm_bcd_be(replystr.substr(p+8, 5), 10);
 			int bandmode = replystr[p+13];
 			int bandfilter = replystr[p+14];
 			int banddata = replystr[p+15] & 0x10;
@@ -1494,7 +1508,7 @@ void RIG_IC7600::get_band_selection(int v)
 
 void RIG_IC7600::set_band_selection(int v)
 {
-	long freq = (useB ? B.freq : A.freq);
+	unsigned long int freq = (useB ? B.freq : A.freq);
 	int fil = (useB ? filB : filA);
 	int mode = (useB ? B.imode : A.imode);
 
