@@ -15,7 +15,7 @@
 // GNU General Public License for more details.
 //
 // You should have received a copy of the GNU General Public License
-// along with this program.  If not, see <http://www.gnu.org/licenses/>.
+// aunsigned long int with this program.  If not, see <http://www.gnu.org/licenses/>.
 // ----------------------------------------------------------------------------
 
 #include <string>
@@ -364,7 +364,7 @@ bool RIG_IC7610::check ()
 //                   ||_________________ 1   Hz  digit
 //                   |__________________ 10  Hz  digit
 
-long RIG_IC7610::get_vfoA ()
+unsigned long int RIG_IC7610::get_vfoA ()
 {
 	string resp;
 
@@ -376,8 +376,12 @@ long RIG_IC7610::get_vfoA ()
 	cmd.append(post);
 	if (waitFOR(12, "get vfo A")) {
 		size_t p = replystr.rfind(resp);
-		if (p != string::npos)
-			A.freq = fm_bcd_be(replystr.substr(p+6), 8);
+		if (p != string::npos) {
+			if (replystr[p+6] == -1)
+				A.freq = 0;
+			else
+				A.freq = fm_bcd_be(replystr.substr(p+6), 8);
+		}
 	}
 
 	get_trace(2, "get_vfoA() ", str2hex(replystr.c_str(), replystr.length()));
@@ -385,7 +389,7 @@ long RIG_IC7610::get_vfoA ()
 	return A.freq;
 }
 
-void RIG_IC7610::set_vfoA (long freq)
+void RIG_IC7610::set_vfoA (unsigned long int freq)
 {
 	A.freq = freq;
 
@@ -400,7 +404,7 @@ void RIG_IC7610::set_vfoA (long freq)
 
 }
 
-long RIG_IC7610::get_vfoB ()
+unsigned long int RIG_IC7610::get_vfoB ()
 {
 	string resp;
 
@@ -412,8 +416,12 @@ long RIG_IC7610::get_vfoB ()
 	cmd.append(post);
 	if (waitFOR(12, "get vfo B")) {
 		size_t p = replystr.rfind(resp);
-		if (p != string::npos)
-			B.freq = fm_bcd_be(replystr.substr(p+6), 8);
+		if (p != string::npos) {
+			if (replystr[p+6] == -1)
+				A.freq = 0;
+			else
+				B.freq = fm_bcd_be(replystr.substr(p+6), 8);
+		}
 	}
 
 	get_trace(2, "get_vfoB() ", str2hex(replystr.c_str(), replystr.length()));
@@ -421,7 +429,7 @@ long RIG_IC7610::get_vfoB ()
 	return B.freq;
 }
 
-void RIG_IC7610::set_vfoB (long freq)
+void RIG_IC7610::set_vfoB (unsigned long int freq)
 {
 	B.freq = freq;
 
@@ -469,6 +477,8 @@ int RIG_IC7610::get_modeA()
 		if (p == string::npos)
 			goto end_wait_modeA;
 
+		if (replystr[p+6] == -1) { A.imode = A.filter = 0; return A.imode; }
+
 		for (md = 0; md < m7610LSBD1; md++) {
 			if (replystr[p+6] == IC7610_mode_nbr[md]) {
 				A.imode = md;
@@ -482,8 +492,8 @@ int RIG_IC7610::get_modeA()
 					A.imode = 1;
 				break;
 			}
+			A.filter = replystr[p+8];
 		}
-		A.filter = replystr[p+8];
 	}
 
 end_wait_modeA:
@@ -544,6 +554,8 @@ int RIG_IC7610::get_modeB()
 		if (p == string::npos)
 			goto end_wait_modeB;
 
+		if (replystr[p+6] == -1) { B.imode = B.filter = 0; return B.imode; }
+
 		for (md = 0; md < m7610LSBD1; md++) {
 			if (replystr[p+6] == IC7610_mode_nbr[md]) {
 				B.imode = md;
@@ -1890,7 +1902,7 @@ int RIG_IC7610::get_pbt_outer()
 	cmd = pre_to;
 	cmd.append(cstr);
 	cmd.append( post );
-	if (waitFOR(9, "get pbt inner")) {
+	if (waitFOR(9, "get pbt outer")) {
 		size_t p = replystr.rfind(resp);
 		if (p != string::npos) {
 			val = num100(replystr.substr(p+6));
@@ -2090,7 +2102,7 @@ void RIG_IC7610::get_band_selection(int v)
 		set_trace(2, "get band stack", str2hex(replystr.c_str(), replystr.length()));
 		size_t p = replystr.rfind(pre_fm);
 		if (p != string::npos) {
-			long int bandfreq = fm_bcd_be(replystr.substr(p+8, 5), 10);
+			unsigned long int bandfreq = fm_bcd_be(replystr.substr(p+8, 5), 10);
 			int bandmode = replystr[p+13];
 			int bandfilter = replystr[p+14];
 			int banddata = replystr[p+15] & 0x10;
@@ -2135,7 +2147,7 @@ void RIG_IC7610::get_band_selection(int v)
 
 void RIG_IC7610::set_band_selection(int v)
 {
-	long freq = (useB ? B.freq : A.freq);
+	unsigned long int freq = (useB ? B.freq : A.freq);
 	int fil = (useB ? filB : filA);
 	int mode = (useB ? B.imode : A.imode);
 
