@@ -15,7 +15,7 @@
 // GNU General Public License for more details.
 //
 // You should have received a copy of the GNU General Public License
-// along with this program.  If not, see <http://www.gnu.org/licenses/>.
+// aunsigned long int with this program.  If not, see <http://www.gnu.org/licenses/>.
 // ----------------------------------------------------------------------------
 
 #include <sstream>
@@ -274,7 +274,7 @@ bool RIG_IC9100::check ()
 	return ok;
 }
 
-long RIG_IC9100::get_vfoA ()
+unsigned long int RIG_IC9100::get_vfoA ()
 {
 	if (useB) return A.freq;
 	string resp = pre_fm;
@@ -284,14 +284,18 @@ long RIG_IC9100::get_vfoA ()
 	cmd.append( post );
 	if (waitFOR(11, "get vfo A")) {
 		size_t p = replystr.rfind(resp);
-		if (p != string::npos)
-			A.freq = fm_bcd_be(replystr.substr(p+5), 10);
+		if (p != string::npos) {
+			if (replystr[p+5] == -1)
+				A.freq = 0;
+			else
+				A.freq = fm_bcd_be(replystr.substr(p+5), 10);
+		}
 	}
 	get_trace(2, "get_vfoA()", str2hex(replystr.c_str(), replystr.length()));
 	return A.freq;
 }
 
-void RIG_IC9100::set_vfoA (long freq)
+void RIG_IC9100::set_vfoA (unsigned long int freq)
 {
 	A.freq = freq;
 	cmd = pre_to;
@@ -302,7 +306,7 @@ void RIG_IC9100::set_vfoA (long freq)
 	set_trace(2, "set_vfoA()", str2hex(replystr.c_str(), replystr.length()));
 }
 
-long RIG_IC9100::get_vfoB ()
+unsigned long int RIG_IC9100::get_vfoB ()
 {
 	if (!useB) return B.freq;
 	string resp = pre_fm;
@@ -312,14 +316,18 @@ long RIG_IC9100::get_vfoB ()
 	cmd.append( post );
 	if (waitFOR(11, "get vfo B")) {
 		size_t p = replystr.rfind(resp);
-		if (p != string::npos)
-			B.freq = fm_bcd_be(replystr.substr(p+5), 10);
+		if (p != string::npos) {
+			if (replystr[p+5] == -1)
+				A.freq = 0;
+			else
+				B.freq = fm_bcd_be(replystr.substr(p+5), 10);
+		}
 	}
 	get_trace(2, "get_vfoB()", str2hex(replystr.c_str(), replystr.length()));
 	return B.freq;
 }
 
-void RIG_IC9100::set_vfoB (long freq)
+void RIG_IC9100::set_vfoB (unsigned long int freq)
 {
 	B.freq = freq;
 	cmd = pre_to;
@@ -369,6 +377,9 @@ int RIG_IC9100::get_modeA()
 	if (ret) {
 		size_t p = replystr.find(resp);
 		if (p != std::string::npos) {
+
+			if (replystr[p+5] == -1) { A.imode = 0; return A.imode; }
+
 			for (md = 0; md < nummodes; md++)
 				if (replystr[p+5] == IC9100_mode_nbr[md])
 					break;
@@ -447,6 +458,9 @@ int RIG_IC9100::get_modeB()
 	if (ret) {
 		size_t p = replystr.find(resp);
 		if (p != std::string::npos) {
+
+			if (replystr[p+5] == -1) { B.imode = 0; return B.imode; }
+
 			for (md = 0; md < nummodes; md++)
 				if (replystr[p+5] == IC9100_mode_nbr[md])
 					break;
@@ -657,42 +671,87 @@ int RIG_IC9100::def_bandwidth(int m)
 
 void RIG_IC9100::set_mic_gain(int val)
 {
-	if (!progStatus.USBaudio) {
-		cmd = pre_to;
-		cmd.append("\x14\x0B");
-		cmd.append(bcd255(val));
-		cmd.append( post );
-	} else {
-		cmd = pre_to;
-		cmd += '\x1A'; cmd += '\x05';
-		cmd += '\x00'; cmd += '\x29';
-		cmd.append(bcd255(val));
-		cmd.append( post );
-	}
+	cmd = pre_to;
+	cmd.append("\x14\x0B");
+	cmd.append(bcd255(val));
+	cmd.append( post );
 	waitFB("set mic gain");
 	set_trace(2, "set_mic_gain()", str2hex(replystr.c_str(), replystr.length()));
 }
 
+int RIG_IC9100::get_mic_gain()
+{
+	int val = 0;
+	string cstr = "\x14\x0B";
+	string resp = pre_fm;
+	resp.append(cstr);
+	cmd = pre_to;
+	cmd.append(cstr);
+	cmd.append(post);
+	if (waitFOR(9, "get mic")) {
+		size_t p = replystr.rfind(resp);
+		if (p != string::npos)
+			val = num100(replystr.substr(p + 6));
+	}
+	get_trace(2, "get_mic_gain()", str2hex(replystr.c_str(), replystr.length()));
+	return val;
+}
+
+void RIG_IC9100::get_mic_gain_min_max_step(int &min, int &max, int &step)
+{
+	min = 0;
+	max = 100;
+	step = 1;
+}
+
+static int comp_level[] = {11,34,58,81,104,128,151,174,197,221,244};
 void RIG_IC9100::set_compression(int on, int val)
 {
-	if (on) {
-		cmd.assign(pre_to).append("\x14\x0E");
-		cmd.append(bcd255(val));
-		cmd.append( post );
-		waitFB("set comp");
+	cmd = pre_to;
+	cmd.append("\x16\x44");
+	if (on) cmd += '\x01';
+	else cmd += '\x00';
+	cmd.append(post);
+	waitFB("set Comp ON/OFF");
+	set_trace(2, "set Comp ON/OFF", str2hex(cmd.c_str(), cmd.length()));
+	if (val < 0) return;
+	if (val > 10) return;
 
-		cmd = pre_to;
-		cmd.append("\x16\x44");
-		cmd += '\x01';
-		cmd.append(post);
-		waitFB("set Comp ON");
-	} else{
-		cmd.assign(pre_to).append("\x16\x44");
-		cmd += '\x00';
-		cmd.append(post);
-		waitFB("set Comp OFF");
+	cmd.assign(pre_to).append("\x14\x0E");
+	cmd.append(to_bcd(comp_level[val], 3));
+	cmd.append( post );
+	waitFB("set comp");
+	set_trace(2, "set Comp", str2hex(cmd.c_str(), cmd.length()));
+}
+
+void RIG_IC9100::get_compression(int &on, int &val)
+{
+	std::string resp;
+
+	cmd.assign(pre_to).append("\x16\x44").append(post);
+
+	resp.assign(pre_fm).append("\x16\x44");
+
+	if (waitFOR(8, "get comp on/off")) {
+		size_t p = replystr.find(resp);
+		if (p != string::npos)
+			on = (replystr[p+6] == 0x01);
+	}
+	get_trace(2, "get comp on/off", str2hex(replystr.c_str(), replystr.length()));
+
+	cmd.assign(pre_to).append("\x14\x0E").append(post);
+	resp.assign(pre_fm).append("\x14\x0E");
+
+	if (waitFOR(9, "get comp level")) {
+		size_t p = replystr.find(resp);
+		int level = 0;
+		if (p != string::npos) {
+			level = fm_bcd(replystr.substr(p+6), 3);
+			for (val = 0; val < 11; val++)
+				if (level <= comp_level[val]) break;
+		}
+		get_trace(2, "get comp level", str2hex(replystr.c_str(), replystr.length()));
 	}
-	set_trace(2, "set_compression()", str2hex(replystr.c_str(), replystr.length()));
 }
 
 void RIG_IC9100::set_vox_onoff()
@@ -932,7 +991,24 @@ int RIG_IC9100::get_smeter()
 	return mtr;
 }
 
-int RIG_IC9100::get_power_out()
+struct pwrpair {int mtr; float pwr;};
+
+static pwrpair pwrtbl[] = { 
+	{0, 0.0},
+	{21, 5.0},
+	{43,10.0}, 
+	{65, 15.0},
+	{83, 20.0}, 
+	{95, 25.0}, 
+	{105, 30.0},
+	{114, 35.0}, 
+	{124, 40.0}, 
+	{143, 50.0}, 
+	{183, 75.0},
+	{213, 100.0},
+	{255, 120.0 } };
+
+int RIG_IC9100::get_power_out(void)
 {
 	string cstr = "\x15\x11";
 	string resp = pre_fm;
@@ -940,20 +1016,40 @@ int RIG_IC9100::get_power_out()
 	cmd = pre_to;
 	cmd.append(cstr);
 	cmd.append( post );
-	int mtr= -1;
-	if (waitFOR(9, "get pout")) {
+	int mtr= 0;
+	if (waitFOR(9, "get power out")) {
 		size_t p = replystr.rfind(resp);
 		if (p != string::npos) {
 			mtr = fm_bcd(replystr.substr(p+6), 3);
-			mtr = (int)ceil(mtr /2.15);
+			size_t i = 0;
+			for (i = 0; i < sizeof(pwrtbl) / sizeof(pwrpair) - 1; i++)
+				if (mtr >= pwrtbl[i].mtr && mtr < pwrtbl[i+1].mtr)
+					break;
+			if (mtr < 0) mtr = 0;
+			if (mtr > 255) mtr = 255;
+			mtr = (int)ceil(pwrtbl[i].pwr + 
+				(pwrtbl[i+1].pwr - pwrtbl[i].pwr)*(mtr - pwrtbl[i].mtr)/(pwrtbl[i+1].mtr - pwrtbl[i].mtr));
+			
 			if (mtr > 100) mtr = 100;
 		}
 	}
-	get_trace(2, "get_power_out()", str2hex(replystr.c_str(), replystr.length()));
 	return mtr;
 }
 
-int RIG_IC9100::get_swr()
+struct swrpair {int mtr; float swr;};
+
+// Table entries below correspond to SWR readings of 1.1, 1.5, 2.0, 2.5, 3.0 and infinity.
+// Values are also tweaked to fit the display of the SWR meter.
+
+static swrpair swrtbl[] = { 
+	{0, 0.0},
+	{48, 10.5},
+	{80, 23.0}, 
+	{103, 35.0},
+	{120, 48.0},
+	{255, 100.0 } };
+
+int RIG_IC9100::get_swr(void)
 {
 	string cstr = "\x15\x12";
 	string resp = pre_fm;
@@ -962,15 +1058,22 @@ int RIG_IC9100::get_swr()
 	cmd.append(cstr);
 	cmd.append( post );
 	int mtr= -1;
-	if (waitFOR(9, "get SWR")) {
+	if (waitFOR(9, "get swr")) {
 		size_t p = replystr.rfind(resp);
 		if (p != string::npos) {
 			mtr = fm_bcd(replystr.substr(p+6), 3);
-			mtr = (int)ceil(mtr /2.40);
+			size_t i = 0;
+			for (i = 0; i < sizeof(swrtbl) / sizeof(swrpair) - 1; i++)
+				if (mtr >= swrtbl[i].mtr && mtr < swrtbl[i+1].mtr)
+					break;
+			if (mtr < 0) mtr = 0;
+			if (mtr > 255) mtr = 255;
+			mtr = (int)ceil(swrtbl[i].swr + 
+				(swrtbl[i+1].swr - swrtbl[i].swr)*(mtr - swrtbl[i].mtr)/(swrtbl[i+1].mtr - swrtbl[i].mtr));
+
 			if (mtr > 100) mtr = 100;
 		}
 	}
-	get_trace(2, "get_swr()", str2hex(replystr.c_str(), replystr.length()));
 	return mtr;
 }
 
@@ -1605,7 +1708,7 @@ void RIG_IC9100::get_band_selection(int v)
 		set_trace(2, "get band stack", str2hex(replystr.c_str(), replystr.length()));
 		size_t p = replystr.rfind(pre_fm);
 		if (p != string::npos) {
-			long int bandfreq = fm_bcd_be(replystr.substr(p+8, 5), 10);
+			unsigned long int bandfreq = fm_bcd_be(replystr.substr(p+8, 5), 10);
 			int bandmode = replystr[p+13];
 			int bandfilter = replystr[p+14];
 			int banddata = replystr[p+15] & 0x10;
@@ -1638,7 +1741,7 @@ void RIG_IC9100::get_band_selection(int v)
 
 void RIG_IC9100::set_band_selection(int v)
 {
-	long freq = (useB ? B.freq : A.freq);
+	unsigned long int freq = (useB ? B.freq : A.freq);
 	int mode = (useB ? B.imode : A.imode);
 
 	cmd.assign(pre_to);
