@@ -15,7 +15,7 @@
 // GNU General Public License for more details.
 //
 // You should have received a copy of the GNU General Public License
-// along with this program.  If not, see <http://www.gnu.org/licenses/>.
+// aunsigned long int with this program.  If not, see <http://www.gnu.org/licenses/>.
 // ----------------------------------------------------------------------------
 
 #include <sstream>
@@ -302,7 +302,7 @@ bool RIG_IC9700::check ()
 	return ok;
 }
 
-long RIG_IC9700::get_vfoA ()
+unsigned long int RIG_IC9700::get_vfoA ()
 {
 	if (useB) return A.freq;
 	string resp = pre_fm;
@@ -312,14 +312,18 @@ long RIG_IC9700::get_vfoA ()
 	cmd.append( post );
 	if (waitFOR(11, "get vfo A")) {
 		size_t p = replystr.rfind(resp);
-		if (p != string::npos)
-			A.freq = fm_bcd_be(replystr.substr(p+5), 10);
+		if (p != string::npos) {
+			if (replystr[p+5] == -1)
+				A.freq = 0;
+			else
+				A.freq = fm_bcd_be(replystr.substr(p+5), 10);
+		}
 	}
 	get_trace(2, "get_vfoA()", str2hex(replystr.c_str(), replystr.length()));
 	return A.freq;
 }
 
-void RIG_IC9700::set_vfoA (long freq)
+void RIG_IC9700::set_vfoA (unsigned long int freq)
 {
 	A.freq = freq;
 	cmd = pre_to;
@@ -330,7 +334,7 @@ void RIG_IC9700::set_vfoA (long freq)
 	set_trace(2, "set_vfoA()", str2hex(replystr.c_str(), replystr.length()));
 }
 
-long RIG_IC9700::get_vfoB ()
+unsigned long int RIG_IC9700::get_vfoB ()
 {
 	if (!useB) return B.freq;
 	string resp = pre_fm;
@@ -340,14 +344,18 @@ long RIG_IC9700::get_vfoB ()
 	cmd.append( post );
 	if (waitFOR(11, "get vfo B")) {
 		size_t p = replystr.rfind(resp);
-		if (p != string::npos)
-			B.freq = fm_bcd_be(replystr.substr(p+5), 10);
+		if (p != string::npos) {
+			if (replystr[p+5] == -1)
+				A.freq = 0;
+			else
+				B.freq = fm_bcd_be(replystr.substr(p+5), 10);
+		}
 	}
 	get_trace(2, "get_vfoB()", str2hex(replystr.c_str(), replystr.length()));
 	return B.freq;
 }
 
-void RIG_IC9700::set_vfoB (long freq)
+void RIG_IC9700::set_vfoB (unsigned long int freq)
 {
 	B.freq = freq;
 	cmd = pre_to;
@@ -397,6 +405,9 @@ int RIG_IC9700::get_modeA()
 	if (ret) {
 		size_t p = replystr.find(resp);
 		if (p != std::string::npos) {
+
+			if (replystr[p+5] == -1) { A.imode = 0; return A.imode; }
+
 			for (md = 0; md < nummodes; md++)
 				if (replystr[p+5] == IC9700_mode_nbr[md])
 					break;
@@ -475,6 +486,9 @@ int RIG_IC9700::get_modeB()
 	if (ret) {
 		size_t p = replystr.find(resp);
 		if (p != std::string::npos) {
+
+			if (replystr[p+5] == -1) { B.imode = 0; return B.imode; }
+
 			for (md = 0; md < nummodes; md++)
 				if (replystr[p+5] == IC9700_mode_nbr[md])
 					break;
@@ -685,22 +699,39 @@ int RIG_IC9700::def_bandwidth(int m)
 
 void RIG_IC9700::set_mic_gain(int val)
 {
-	if (!progStatus.USBaudio) {
-		cmd = pre_to;
-		cmd.append("\x14\x0B");
-		cmd.append(bcd255(val));
-		cmd.append( post );
-	} else {
-		cmd = pre_to;
-		cmd += '\x1A'; cmd += '\x05';
-		cmd += '\x00'; cmd += '\x29';
-		cmd.append(bcd255(val));
-		cmd.append( post );
-	}
+	cmd = pre_to;
+	cmd.append("\x14\x0B");
+	cmd.append(bcd255(val));
+	cmd.append( post );
 	waitFB("set mic gain");
 	set_trace(2, "set_mic_gain()", str2hex(replystr.c_str(), replystr.length()));
 }
 
+int RIG_IC9700::get_mic_gain()
+{
+	int val = 0;
+	string cstr = "\x14\x0B";
+	string resp = pre_fm;
+	resp.append(cstr);
+	cmd = pre_to;
+	cmd.append(cstr);
+	cmd.append(post);
+	if (waitFOR(9, "get mic")) {
+		size_t p = replystr.rfind(resp);
+		if (p != string::npos)
+			val = num100(replystr.substr(p + 6));
+	}
+	get_trace(2, "get_mic_gain()", str2hex(replystr.c_str(), replystr.length()));
+	return val;
+}
+
+void RIG_IC9700::get_mic_gain_min_max_step(int &min, int &max, int &step)
+{
+	min = 0;
+	max = 100;
+	step = 1;
+}
+
 void RIG_IC9700::set_compression(int on, int val)
 {
 	if (on) {
@@ -1633,7 +1664,7 @@ void RIG_IC9700::get_band_selection(int v)
 		set_trace(2, "get band stack", str2hex(replystr.c_str(), replystr.length()));
 		size_t p = replystr.rfind(pre_fm);
 		if (p != string::npos) {
-			long int bandfreq = fm_bcd_be(replystr.substr(p+8, 5), 10);
+			unsigned long int bandfreq = fm_bcd_be(replystr.substr(p+8, 5), 10);
 			int bandmode = replystr[p+13];
 			int bandfilter = replystr[p+14];
 			int banddata = replystr[p+15] & 0x10;
@@ -1666,7 +1697,7 @@ void RIG_IC9700::get_band_selection(int v)
 
 void RIG_IC9700::set_band_selection(int v)
 {
-	long freq = (useB ? B.freq : A.freq);
+	unsigned long int freq = (useB ? B.freq : A.freq);
 	int mode = (useB ? B.imode : A.imode);
 
 	cmd.assign(pre_to);
