@@ -15,7 +15,7 @@
 // GNU General Public License for more details.
 //
 // You should have received a copy of the GNU General Public License
-// along with this program.  If not, see <http://www.gnu.org/licenses/>.
+// aunsigned long int with this program.  If not, see <http://www.gnu.org/licenses/>.
 // ----------------------------------------------------------------------------
 #include <iostream>
 #include <sstream>
@@ -275,7 +275,7 @@ bool RIG_ICF8101::check ()
 	return ok;
 }
 
-long RIG_ICF8101::get_vfoA ()
+unsigned long int RIG_ICF8101::get_vfoA ()
 {
 	if (useB) return A.freq;
 	string resp = pre_fm;
@@ -292,7 +292,7 @@ long RIG_ICF8101::get_vfoA ()
 	return A.freq;
 }
 
-void RIG_ICF8101::set_vfoA (long freq)
+void RIG_ICF8101::set_vfoA (unsigned long int freq)
 {
 	A.freq = freq;
 	cmd = pre_to;
@@ -304,7 +304,7 @@ void RIG_ICF8101::set_vfoA (long freq)
 	waitFB("set vfo A");
 }
 
-long RIG_ICF8101::get_vfoB ()
+unsigned long int RIG_ICF8101::get_vfoB ()
 {
 	if (!useB) return B.freq;
 	string resp = pre_fm;
@@ -321,7 +321,7 @@ long RIG_ICF8101::get_vfoB ()
 	return B.freq;
 }
 
-void RIG_ICF8101::set_vfoB (long freq)
+void RIG_ICF8101::set_vfoB (unsigned long int freq)
 {
 	B.freq = freq;
 	cmd = pre_to;
