@@ -15,7 +15,7 @@
 // GNU General Public License for more details.
 //
 // You should have received a copy of the GNU General Public License
-// along with this program.  If not, see <http://www.gnu.org/licenses/>.
+// aunsigned long int with this program.  If not, see <http://www.gnu.org/licenses/>.
 // ----------------------------------------------------------------------------
 
 #include "TS140.h"
@@ -112,20 +112,20 @@ bool RIG_TS140::check ()
 	return true;
 }
 
-long RIG_TS140::get_vfoA ()
+unsigned long int RIG_TS140::get_vfoA ()
 {
 	cmd = "IF;";
 	int ret = wait_char(';', 38, 100, "get VFO", ASC);
 	if (ret < 38) return freqA;
 
-	long f = 0;
+	unsigned long int f = 0;
 	for (size_t n = 2; n < 13; n++)
 		f = f*10 + replybuff[ret - 38 + n] - '0';
 	freqA = f;
 	return freqA;
 }
 
-void RIG_TS140::set_vfoA (long freq)
+void RIG_TS140::set_vfoA (unsigned long int freq)
 {
 	freqA = freq;
 	cmd = "FA00000000000;";
