@@ -15,7 +15,7 @@
 // GNU General Public License for more details.
 //
 // You should have received a copy of the GNU General Public License
-// along with this program.  If not, see <http://www.gnu.org/licenses/>.
+// aunsigned long int with this program.  If not, see <http://www.gnu.org/licenses/>.
 // ----------------------------------------------------------------------------
 
 #include "TS450S.h"
@@ -94,7 +94,7 @@ bool RIG_TS450S::check ()
 	return true;
 }
 
-long RIG_TS450S::get_vfoA ()
+unsigned long int RIG_TS450S::get_vfoA ()
 {
 	cmd = "FA;";
 
@@ -111,7 +111,7 @@ long RIG_TS450S::get_vfoA ()
 	return freqA;
 }
 
-void RIG_TS450S::set_vfoA (long freq)
+void RIG_TS450S::set_vfoA (unsigned long int freq)
 {
 	freqA = freq;
 	cmd = "FA00000000000;";
@@ -123,7 +123,7 @@ void RIG_TS450S::set_vfoA (long freq)
 	showresp(WARN, ASC, "set vfo A", cmd, "");
 }
 
-long RIG_TS450S::get_vfoB ()
+unsigned long int RIG_TS450S::get_vfoB ()
 {
 	cmd = "FB;";
 	int ret = wait_char(';', 14, 100, "get vfo B", ASC);
@@ -139,7 +139,7 @@ long RIG_TS450S::get_vfoB ()
 	return freqB;
 }
 
-void RIG_TS450S::set_vfoB (long freq)
+void RIG_TS450S::set_vfoB (unsigned long int freq)
 {
 	freqB = freq;
 	cmd = "FB00000000000;";
