@@ -15,7 +15,7 @@
 // GNU General Public License for more details.
 //
 // You should have received a copy of the GNU General Public License
-// along with this program.  If not, see <http://www.gnu.org/licenses/>.
+// aunsigned long int with this program.  If not, see <http://www.gnu.org/licenses/>.
 // ----------------------------------------------------------------------------
 //
 // Changes for the TS-870S March 2012, Dave Baxter, G0WBX
@@ -352,7 +352,7 @@ bool RIG_TS870S::check ()
 	return true;
 }
 
-long RIG_TS870S::get_vfoA ()
+unsigned long int RIG_TS870S::get_vfoA ()
 {
 	cmd = "FA;";
 	if (wait_char(';', 14, 100, "get vfoA", ASC) < 14) return A.freq;
@@ -360,8 +360,8 @@ long RIG_TS870S::get_vfoA ()
 	size_t p = replystr.rfind("FA");
 	if (p == string::npos) return A.freq;
 
-	long f = 0L;
-	long mul = 1L;
+	unsigned long int f = 0L;
+	unsigned long int mul = 1L;
 	for (size_t n = 12; n > 1; n--) {
 		f += (replystr[p + n] - '0') * mul;
 		mul *= 10;
@@ -371,7 +371,7 @@ long RIG_TS870S::get_vfoA ()
 }
 
 //----------------------------------------------------------------------
-void RIG_TS870S::set_vfoA (long freq)
+void RIG_TS870S::set_vfoA (unsigned long int freq)
 {
 	A.freq = freq;
 	cmd = "FA00000000000;";
@@ -384,7 +384,7 @@ void RIG_TS870S::set_vfoA (long freq)
 }
 
 //----------------------------------------------------------------------
-long RIG_TS870S::get_vfoB ()
+unsigned long int RIG_TS870S::get_vfoB ()
 {
 	cmd = "FB;";
 	if (wait_char(';', 14, 100, "get vfoB", ASC) < 14) return B.freq;
@@ -392,8 +392,8 @@ long RIG_TS870S::get_vfoB ()
 	size_t p = replystr.rfind("FB");
 	if (p == string::npos) return B.freq;
 
-	long f = 0L;
-	long mul = 1L;
+	unsigned long int f = 0L;
+	unsigned long int mul = 1L;
 	for (size_t n = 12; n > 1; n--) {
 		f += (replystr[p + n] - '0') * mul;
 		mul *= 10;
@@ -404,7 +404,7 @@ long RIG_TS870S::get_vfoB ()
 }
 
 //----------------------------------------------------------------------
-void RIG_TS870S::set_vfoB (long freq)
+void RIG_TS870S::set_vfoB (unsigned long int freq)
 {
 	B.freq = freq;
 	cmd = "FB00000000000;";
