@@ -15,7 +15,7 @@
 // GNU General Public License for more details.
 //
 // You should have received a copy of the GNU General Public License
-// along with this program.  If not, see <http://www.gnu.org/licenses/>.
+// aunsigned long int with this program.  If not, see <http://www.gnu.org/licenses/>.
 // ----------------------------------------------------------------------------
 /*
  * Copyright (c) 2014 Andy Burnett, G0HIX
@@ -727,7 +727,7 @@ bool RIG_TS990::check ()
 	return true;
 }
 
-long RIG_TS990::get_vfoA ()
+unsigned long int RIG_TS990::get_vfoA ()
 {
 	ts990debug("get_vfoA()");
 
@@ -737,8 +737,8 @@ long RIG_TS990::get_vfoA ()
 	size_t p = replystr.rfind("FA");
 	if (p == string::npos) return A.freq;
 
-	long f = 0L;
-	long mul = 1L;
+	unsigned long int f = 0L;
+	unsigned long int mul = 1L;
 	for (size_t n = 12; n > 1; n--) {
 		f += (replystr[p + n] - '0') * mul;
 		mul *= 10;
@@ -747,9 +747,9 @@ long RIG_TS990::get_vfoA ()
 	return A.freq;
 }
 
-void RIG_TS990::set_vfoA (long freq)
+void RIG_TS990::set_vfoA (unsigned long int freq)
 {
-	ts990debug("set_vfoA(long freq)");
+	ts990debug("set_vfoA(unsigned long int freq)");
 
 	A.freq = freq;
 	cmd = "FA00000000000;";
@@ -761,7 +761,7 @@ void RIG_TS990::set_vfoA (long freq)
 	showresp(INFO, ASC, "set vfo A", cmd, "");
 }
 
-long RIG_TS990::get_vfoB ()
+unsigned long int RIG_TS990::get_vfoB ()
 {
 	ts990debug("get_vfoB()");
 
@@ -771,8 +771,8 @@ long RIG_TS990::get_vfoB ()
 	size_t p = replystr.rfind("FB");
 	if (p == string::npos) return B.freq;
 
-	long f = 0L;
-	long mul = 1L;
+	unsigned long int f = 0L;
+	unsigned long int mul = 1L;
 	for (size_t n = 12; n > 1; n--) {
 		f += (replystr[p + n] - '0') * mul;
 		mul *= 10;
@@ -782,9 +782,9 @@ long RIG_TS990::get_vfoB ()
 	return B.freq;
 }
 
-void RIG_TS990::set_vfoB (long freq)
+void RIG_TS990::set_vfoB (unsigned long int freq)
 {
-	ts990debug("set_vfoB(long freq)");
+	ts990debug("set_vfoB(unsigned long int freq)");
 
 	B.freq = freq;
 	cmd = "FB00000000000;";
