@@ -245,7 +245,7 @@ public:
 		}
 		if (selrig->has_power_out && btnPTT->value()) {
 			static char szval[10];
-			snprintf(szval, sizeof(szval), "P:%d\n", (int)mval);
+			snprintf(szval, sizeof(szval), "P:%d\n", (int)pwrval);
 			info.append(szval);
 		}
 
@@ -1063,6 +1063,17 @@ public:
 	}
 } rig_get_smeter(&rig_server);
 
+class rig_get_pwrmeter_scale : public XmlRpcServerMethod {
+public:
+	rig_get_pwrmeter_scale(XmlRpcServer* s) : XmlRpcServerMethod("rig.get_pwrmeter_scale", s) {}
+
+	void execute(XmlRpcValue& params, XmlRpcValue& result) {
+		if (!xcvr_initialized || !selrig->has_power_out)
+			result = (int)(0);
+		else
+			result = (int)(selrig->power_scale());
+	}
+} rig_get_pwrmeter_scale(&rig_server);
 
 class rig_get_pwrmeter : public XmlRpcServerMethod {
 public:
@@ -1072,10 +1083,21 @@ public:
 		if (!xcvr_initialized || !selrig->has_power_out) 
 			result = (int)(0);
 		else
-			result = (int)(mval);
+			result = (int)(pwrval);
 	}
 } rig_get_pwrmeter(&rig_server);
 
+class rig_get_swrmeter : public XmlRpcServerMethod {
+public:
+	rig_get_swrmeter(XmlRpcServer* s) : XmlRpcServerMethod("rig.get_swrmeter", s) {}
+
+	void execute(XmlRpcValue& params, XmlRpcValue& result) {
+		if (!xcvr_initialized || !selrig->has_swr_control) 
+			result = (int)(0);
+		else
+			result = (int)(swrval);
+	}
+} rig_get_swrmeter(&rig_server);
 
 class rig_get_power : public XmlRpcServerMethod {
 public:
@@ -1798,10 +1820,11 @@ public:
 		{
 			guard_lock lock1(&mutex_srvc_reqs);
 			guard_lock lock2(&mutex_serial);
-			sendCommand(cmd, 0, 0);//cmd.length());
+
+			RigSerial->WriteBuffer(cmd.c_str(), cmd.length());
 
 			retstr.clear();
-			waitResponse(100);
+			waitResponse(10);//(100);
 			if (!respstr.empty()) {
 				retstr = usehex ? 
 					str2hex(respstr.c_str(), respstr.length()) :
@@ -1811,14 +1834,53 @@ public:
 				result = std::string("No response: ").append(selrig->name_);
 		}
 
-	xml_trace(2, "xmlrpc command:", command.c_str());
-
+		xml_trace(2, "xmlrpc command:", command.c_str());
 	}
 
 	std::string help() { return std::string("sends xmlrpc CAT string to xcvr"); }
 
 } rig_cat_string(&rig_server);
 
+class rig_cat_priority : public XmlRpcServerMethod {
+public:
+	rig_cat_priority(XmlRpcServer* s) : XmlRpcServerMethod("rig.cat_priority", s) {}
+
+	void execute(XmlRpcValue& params, XmlRpcValue& result) {
+		result = 0;
+		if (!xcvr_initialized) {
+			return;
+		}
+		std::string command = std::string(params[0]);
+		bool usehex = false;
+		if (command.empty()) return;
+
+		std::string cmd = "";
+		if (command.find("x") != string::npos) { // hex strings
+			size_t p = 0;
+			unsigned int val;
+			usehex = true;
+			while (( p = command.find("x", p)) != string::npos) {
+				sscanf(&command[p+1], "%x", &val);
+				cmd += (unsigned char) val;
+				p += 3;
+			}
+		} else
+			cmd = command;
+
+		guard_lock lock1(&mutex_srvc_reqs);
+		guard_lock lock2(&mutex_serial);
+
+		RigSerial->WriteBuffer(cmd.c_str(), cmd.length());
+		result = std::string("OK");
+
+		return;
+	}
+
+	std::string help() { return std::string("sends xmlrpc priority CAT string to xcvr"); }
+
+} rig_cat_priority(&rig_server);
+
+
 //------------------------------------------------------------------------------
 // Set cwio words per minute
 //------------------------------------------------------------------------------
@@ -1943,6 +2005,8 @@ struct MLIST {
 	{ "rig.get_ptt",      "s:n", "return PTT state" },
 	{ "rig.get_power",    "s:n", "return power level control value" },
 	{ "rig.get_pwrmeter", "s:n", "return PWR out" },
+	{ "rig.get_pwrmeter_scale", "s:n", "return scale for power meter" },
+	{ "rig.get_swrmeter", "s:n", "return SWR out" },
 	{ "rig.get_smeter",   "s:n", "return Smeter" },
 	{ "rig.get_split",    "s:n", "return split state" },
 	{ "rig.get_update",   "s:n", "return update to info" },
@@ -1973,6 +2037,7 @@ struct MLIST {
 	{ "rig.set_micgain",  "i:i", "sets mic gain control" },
 	{ "rig.swap",         "i:i", "execute vfo swap" },
 	{ "rig.cat_string",   "s:s", "execute CAT string" },
+	{ "rig.cat_priority", "s:s", "priority CAT string" },
 	{ "rig.shutdown",     "i:i", "shutdown xcvr & flrig" },
 	{ "rig.cwio_wpm",     "i:i", "set cwio WPM" },
 	{ "rig.cwio_text",    "s:s", "send text via cwio interface" },
